@@ -12,19 +12,19 @@
 
 # This file handles all flask-restful resources for /v3/limits
 
-import flask
-import flask_restful
 import http.client
 
+import flask
+import flask_restful
+
+from keystone.api import validation
 from keystone.common import json_home
 from keystone.common import provider_api
 from keystone.common import rbac_enforcer
-from keystone.common import validation
 from keystone import exception
 from keystone.limit import schema
 from keystone.server import flask as ks_flask
 
-
 PROVIDERS = provider_api.ProviderAPIs
 ENFORCER = rbac_enforcer.RBACEnforcer
 
@@ -55,11 +55,23 @@ class LimitsResource(ks_flask.ResourceBase):
     member_key = 'limit'
     json_home_resource_status = json_home.Status.EXPERIMENTAL
     get_member_from_driver = PROVIDERS.deferred_provider_lookup(
-        api='unified_limit_api', method='get_limit')
+        api='unified_limit_api', method='get_limit'
+    )
 
-    def _list_limits(self):
-        filters = ['service_id', 'region_id', 'resource_name', 'project_id',
-                   'domain_id']
+    @validation.request_query_schema(schema.limits_index_request_query)
+    @validation.response_body_schema(schema.limits_index_response_body)
+    def get(self):
+        """List limits.
+
+        GET /v3/limits
+        """
+        filters = [
+            'service_id',
+            'region_id',
+            'resource_name',
+            'project_id',
+            'domain_id',
+        ]
 
         ENFORCER.enforce_call(action='identity:list_limits', filters=filters)
 
@@ -89,46 +101,86 @@ class LimitsResource(ks_flask.ResourceBase):
 
         return self.wrap_collection(filtered_refs, hints=hints)
 
-    def _get_limit(self, limit_id):
-        ENFORCER.enforce_call(action='identity:get_limit',
-                              build_target=_build_limit_enforcement_target)
-        ref = PROVIDERS.unified_limit_api.get_limit(limit_id)
-        return self.wrap_member(ref)
-
-    def get(self, limit_id=None):
-        if limit_id is not None:
-            return self._get_limit(limit_id)
-        return self._list_limits()
-
+    @validation.request_body_schema(schema.limits_create_request_body)
+    @validation.response_body_schema(schema.limits_create_response_body)
     def post(self):
+        """Create new limits.
+
+        POST /v3/limits
+        """
         ENFORCER.enforce_call(action='identity:create_limits')
         limits_b = (flask.request.get_json(silent=True, force=True) or {}).get(
-            'limits', {})
-        validation.lazy_validate(schema.limit_create, limits_b)
-        limits = [self._assign_unique_id(self._normalize_dict(limit))
-                  for limit in limits_b]
+            'limits', {}
+        )
+        limits = [
+            self._assign_unique_id(self._normalize_dict(limit))
+            for limit in limits_b
+        ]
         refs = PROVIDERS.unified_limit_api.create_limits(limits)
         refs = self.wrap_collection(refs)
         refs.pop('links')
         return refs, http.client.CREATED
 
+
+class LimitResource(ks_flask.ResourceBase):
+    collection_key = 'limits'
+    member_key = 'limit'
+    json_home_resource_status = json_home.Status.EXPERIMENTAL
+    get_member_from_driver = PROVIDERS.deferred_provider_lookup(
+        api='unified_limit_api', method='get_limit'
+    )
+
+    @validation.request_body_schema(None)
+    @validation.response_body_schema(schema.limit_show_response_body)
+    def get(self, limit_id):
+        """Retrieve an existing limit.
+
+        GET /v3/limits/{limit_id}
+        """
+        ENFORCER.enforce_call(
+            action='identity:get_limit',
+            build_target=_build_limit_enforcement_target,
+        )
+        ref = PROVIDERS.unified_limit_api.get_limit(limit_id)
+        return self.wrap_member(ref)
+
+    @validation.request_body_schema(schema.limit_update_request_body)
+    @validation.response_body_schema(schema.limit_show_response_body)
     def patch(self, limit_id):
+        """Update an existing limit.
+
+        PATCH /v3/limits/{limit_id}
+        """
         ENFORCER.enforce_call(action='identity:update_limit')
         limit = (flask.request.get_json(silent=True, force=True) or {}).get(
-            'limit', {})
-        validation.lazy_validate(schema.limit_update, limit)
+            'limit', {}
+        )
         self._require_matching_id(limit)
         ref = PROVIDERS.unified_limit_api.update_limit(limit_id, limit)
         return self.wrap_member(ref)
 
+    @validation.request_body_schema(None)
+    @validation.response_body_schema(None)
     def delete(self, limit_id):
+        """Delete a limit.
+
+        DELETE /v3/limits/{limit_id}
+        """
         ENFORCER.enforce_call(action='identity:delete_limit')
-        return (PROVIDERS.unified_limit_api.delete_limit(limit_id),
-                http.client.NO_CONTENT)
+        return (
+            PROVIDERS.unified_limit_api.delete_limit(limit_id),
+            http.client.NO_CONTENT,
+        )
 
 
 class LimitModelResource(flask_restful.Resource):
+    @validation.request_body_schema(None)
+    @validation.response_body_schema(schema.limit_model_show_response_body)
     def get(self):
+        """Retrieve enforcement model.
+
+        GET /v3/limits/model
+        """
         ENFORCER.enforce_call(action='identity:get_limit_model')
         model = PROVIDERS.unified_limit_api.get_model()
         return {'model': model}
@@ -137,15 +189,32 @@ class LimitModelResource(flask_restful.Resource):
 class LimitsAPI(ks_flask.APIBase):
     _name = 'limits'
     _import_name = __name__
-    resources = [LimitsResource]
     resource_mapping = [
+        ks_flask.construct_resource_map(
+            resource=LimitsResource,
+            url='/limits',
+            resource_kwargs={},
+            rel="limits",
+            path_vars=None,
+            status=json_home.Status.EXPERIMENTAL,
+        ),
+        ks_flask.construct_resource_map(
+            resource=LimitResource,
+            url='/limits/<string:limit_id>',
+            resource_kwargs={},
+            rel="limit",
+            path_vars={
+                'limit_id': json_home.build_v3_parameter_relation("limit_id")
+            },
+            status=json_home.Status.EXPERIMENTAL,
+        ),
         ks_flask.construct_resource_map(
             resource=LimitModelResource,
             resource_kwargs={},
             url='/limits/model',
             rel='limit_model',
-            status=json_home.Status.EXPERIMENTAL
-        )
+            status=json_home.Status.EXPERIMENTAL,
+        ),
     ]
 
 
