@@ -75,9 +75,7 @@ def _format_token_entity(entity):
     if 'access_secret' in entity:
         formatted_entity.pop('access_secret')
 
-    url = (
-        f'/users/{user_id}/OS-OAUTH1/access_tokens/{access_token_id}' '/roles'
-    )
+    url = f'/users/{user_id}/OS-OAUTH1/access_tokens/{access_token_id}/roles'
 
     formatted_entity.setdefault('links', {})
     formatted_entity['links']['roles'] = ks_flask.base_url(url)
@@ -806,8 +804,12 @@ class UserAccessRuleListResource(ks_flask.ResourceBase):
     collection_key = 'access_rules'
     member_key = 'access_rule'
 
-    @validation.request_query_schema(app_cred_schema.index_request_query)
-    @validation.response_body_schema(app_cred_schema.rule_index_response_body)
+    @validation.request_query_schema(
+        app_cred_schema.access_rule_index_request_query
+    )
+    @validation.response_body_schema(
+        app_cred_schema.access_rule_index_response_body
+    )
     def get(self, user_id):
         """List access rules for user.
 
@@ -830,8 +832,12 @@ class UserAccessRuleGetDeleteResource(ks_flask.ResourceBase):
     collection_key = 'access_rules'
     member_key = 'access_rule'
 
-    @validation.request_query_schema(app_cred_schema.rule_show_request_query)
-    @validation.response_body_schema(app_cred_schema.rule_show_response_body)
+    @validation.request_query_schema(
+        app_cred_schema.access_rule_show_request_query
+    )
+    @validation.response_body_schema(
+        app_cred_schema.access_rule_show_response_body
+    )
     def get(self, user_id, access_rule_id):
         """Get access rule resource.
 
@@ -1019,8 +1025,7 @@ class UserAPI(ks_flask.APIBase):
         ks_flask.construct_resource_map(
             resource=UserAccessRuleGetDeleteResource,
             url=(
-                '/users/<string:user_id>/access_rules/'
-                '<string:access_rule_id>'
+                '/users/<string:user_id>/access_rules/<string:access_rule_id>'
             ),
             resource_kwargs={},
             rel='access_rule',
