@@ -10,18 +10,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""Initial version
+"""Initial version.
 
 Revision ID: 27e647c0fad4
 Revises:
 Create Date: 2021-12-23 11:13:26.305412
 """
 
-import datetime
 import textwrap
 
 from alembic import op
 from oslo_log import log
+from oslo_utils import timeutils
 import sqlalchemy as sql
 
 from keystone.assignment.backends import sql as assignment_sql
@@ -39,15 +39,6 @@ LOG = log.getLogger(__name__)
 
 NULL_DOMAIN_ID = '<<keystone.domain.root>>'
 
-# FIXME(stephenfin): Remove this as soon as we're done reworking the
-# migrations. Until then, this is necessary to allow us to use the native
-# alembic tooling (which won't register opts). Alternatively, maybe
-# the server default *shouldn't* rely on a (changeable) config option value?
-try:
-    service_provider_relay_state_prefix_default = CONF.saml.relay_state_prefix
-except Exception:
-    service_provider_relay_state_prefix_default = 'ss:mem:'
-
 
 def upgrade():
     bind = op.get_bind()
@@ -55,8 +46,7 @@ def upgrade():
     if bind.engine.name == 'mysql':
         # Set default DB charset to UTF8.
         op.execute(
-            'ALTER DATABASE %s DEFAULT CHARACTER SET utf8'
-            % bind.engine.url.database
+            f'ALTER DATABASE {bind.engine.url.database} DEFAULT CHARACTER SET utf8'
         )
 
     op.create_table(
@@ -98,11 +88,7 @@ def upgrade():
         sql.Column('role_id', sql.String(64), nullable=False),
         sql.Column('inherited', sql.Boolean, default=False, nullable=False),
         sql.PrimaryKeyConstraint(
-            'type',
-            'actor_id',
-            'target_id',
-            'role_id',
-            'inherited',
+            'type', 'actor_id', 'target_id', 'role_id', 'inherited'
         ),
         sql.Index('ix_actor_id', 'actor_id'),
         mysql_engine='InnoDB',
@@ -118,8 +104,7 @@ def upgrade():
         sql.Column('external_id', sql.String(64)),
         sql.Column('user_id', sql.String(64)),
         sql.UniqueConstraint(
-            'external_id',
-            name='access_rule_external_id_key',
+            'external_id', name='access_rule_external_id_key'
         ),
         sql.UniqueConstraint(
             'user_id',
@@ -158,11 +143,7 @@ def upgrade():
         sql.Column('type', sql.String(length=255), nullable=False),
         sql.Column('extra', ks_sql.JsonBlob.impl),
         sql.Column('key_hash', sql.String(64), nullable=False),
-        sql.Column(
-            'encrypted_blob',
-            ks_sql.Text,
-            nullable=False,
-        ),
+        sql.Column('encrypted_blob', ks_sql.Text, nullable=False),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
     )
@@ -175,9 +156,7 @@ def upgrade():
         sql.Column('description', sql.Text),
         sql.Column('extra', ks_sql.JsonBlob.impl),
         sql.UniqueConstraint(
-            'domain_id',
-            'name',
-            name='ixu_group_name_domain_id',
+            'domain_id', 'name', name='ixu_group_name_domain_id'
         ),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
@@ -198,10 +177,7 @@ def upgrade():
             nullable=False,
         ),
         sql.UniqueConstraint(
-            'domain_id',
-            'local_id',
-            'entity_type',
-            name='domain_id',
+            'domain_id', 'local_id', 'entity_type', name='domain_id'
         ),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
@@ -270,19 +246,13 @@ def upgrade():
         sql.Column(
             'domain_id',
             sql.String(length=64),
-            sql.ForeignKey(
-                'project.id',
-                name='project_domain_id_fkey',
-            ),
+            sql.ForeignKey('project.id', name='project_domain_id_fkey'),
             nullable=False,
         ),
         sql.Column(
             'parent_id',
             sql.String(64),
-            sql.ForeignKey(
-                'project.id',
-                name='project_parent_id_fkey',
-            ),
+            sql.ForeignKey('project.id', name='project_parent_id_fkey'),
             nullable=True,
         ),
         sql.Column(
@@ -293,9 +263,7 @@ def upgrade():
             default=False,
         ),
         sql.UniqueConstraint(
-            'domain_id',
-            'name',
-            name='ixu_project_name_domain_id',
+            'domain_id', 'name', name='ixu_project_name_domain_id'
         ),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
@@ -448,9 +416,7 @@ def upgrade():
         ),
         sql.Column('description', sql.String(255), nullable=True),
         sql.UniqueConstraint(
-            'name',
-            'domain_id',
-            name='ixu_role_name_domain_id',
+            'name', 'domain_id', name='ixu_role_name_domain_id'
         ),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
@@ -510,7 +476,7 @@ def upgrade():
             'relay_state_prefix',
             sql.String(256),
             nullable=False,
-            server_default=service_provider_relay_state_prefix_default,
+            server_default=CONF.saml.relay_state_prefix,
         ),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
@@ -567,16 +533,8 @@ def upgrade():
             'expires_at_int',
             name='duplicate_trust_constraint_expanded',
         ),
-        sql.Column(
-            'redelegated_trust_id',
-            sql.String(64),
-            nullable=True,
-        ),
-        sql.Column(
-            'redelegation_count',
-            sql.Integer,
-            nullable=True,
-        ),
+        sql.Column('redelegated_trust_id', sql.String(64), nullable=True),
+        sql.Column('redelegation_count', sql.Integer, nullable=True),
         mysql_engine='InnoDB',
         mysql_charset='utf8',
     )
@@ -613,18 +571,14 @@ def upgrade():
         sql.Column(
             'user_id',
             sql.String(length=64),
-            sql.ForeignKey(
-                'user.id',
-                name='fk_user_group_membership_user_id',
-            ),
+            sql.ForeignKey('user.id', name='fk_user_group_membership_user_id'),
             primary_key=True,
         ),
         sql.Column(
             'group_id',
             sql.String(length=64),
             sql.ForeignKey(
-                'group.id',
-                name='fk_user_group_membership_group_id',
+                'group.id', name='fk_user_group_membership_group_id'
             ),
             primary_key=True,
         ),
@@ -729,10 +683,7 @@ def upgrade():
         sql.Column(
             'service_id',
             sql.String(length=64),
-            sql.ForeignKey(
-                'service.id',
-                name='endpoint_service_id_fkey',
-            ),
+            sql.ForeignKey('service.id', name='endpoint_service_id_fkey'),
             nullable=False,
         ),
         sql.Column('url', sql.Text, nullable=False),
@@ -747,10 +698,7 @@ def upgrade():
         sql.Column(
             'region_id',
             sql.String(length=255),
-            sql.ForeignKey(
-                'region.id',
-                name='fk_endpoint_region_id',
-            ),
+            sql.ForeignKey('region.id', name='fk_endpoint_region_id'),
             nullable=True,
         ),
         # NOTE(stevemar): The index was named 'service_id' in
@@ -844,10 +792,7 @@ def upgrade():
         # FIXME(stephenfin): This should have a foreign key constraint on
         # registered_limit.id, but sqlalchemy-migrate clearly didn't handle
         # creating a column with embedded FK info as was attempted in 048
-        sql.Column(
-            'registered_limit_id',
-            sql.String(64),
-        ),
+        sql.Column('registered_limit_id', sql.String(64)),
         sql.Column('domain_id', sql.String(64), nullable=True),
         # NOTE(stephenfin): Name chosen to preserve backwards compatibility
         # with names used for primary key unique constraints
@@ -859,12 +804,7 @@ def upgrade():
     op.create_table(
         'local_user',
         sql.Column('id', sql.Integer, primary_key=True, nullable=False),
-        sql.Column(
-            'user_id',
-            sql.String(64),
-            nullable=False,
-            unique=True,
-        ),
+        sql.Column('user_id', sql.String(64), nullable=False, unique=True),
         sql.Column('domain_id', sql.String(64), nullable=False),
         sql.Column('name', sql.String(255), nullable=False),
         sql.Column('failed_auth_count', sql.Integer, nullable=True),
@@ -883,11 +823,7 @@ def upgrade():
         'nonlocal_user',
         sql.Column('domain_id', sql.String(64), primary_key=True),
         sql.Column('name', sql.String(255), primary_key=True),
-        sql.Column(
-            'user_id',
-            sql.String(64),
-            nullable=False,
-        ),
+        sql.Column('user_id', sql.String(64), nullable=False),
         sql.ForeignKeyConstraint(
             ['user_id', 'domain_id'],
             ['user.id', 'user.domain_id'],
@@ -933,7 +869,7 @@ def upgrade():
             'created_at',
             sql.DateTime(),
             nullable=False,
-            default=datetime.datetime.utcnow,
+            default=timeutils.utcnow,
         ),
     )
 
@@ -983,10 +919,7 @@ def upgrade():
         # only for sqlite, once we collapse 073 we can remove this constraint
         with op.batch_alter_table('assignment') as batch_op:
             batch_op.create_foreign_key(
-                'fk_assignment_role_id',
-                'role',
-                ['role_id'],
-                ['id'],
+                'fk_assignment_role_id', 'role', ['role_id'], ['id']
             )
 
     # TODO(stephenfin): Remove these procedures in a future contract migration
@@ -996,7 +929,8 @@ def upgrade():
             'Credential migration in progress. Cannot perform '
             'writes to credential table.'
         )
-        credential_update_trigger = textwrap.dedent(f"""
+        credential_update_trigger = textwrap.dedent(
+            f"""
         CREATE OR REPLACE FUNCTION keystone_read_only_update()
           RETURNS trigger AS
         $BODY$
@@ -1010,7 +944,8 @@ def upgrade():
           RETURN NEW;
         END
         $BODY$ LANGUAGE plpgsql;
-        """)
+        """
+        )
         op.execute(credential_update_trigger)
 
         error_message = (
@@ -1018,7 +953,8 @@ def upgrade():
             'insert new rows into the identity_provider table at '
             'this time.'
         )
-        identity_provider_insert_trigger = textwrap.dedent(f"""
+        identity_provider_insert_trigger = textwrap.dedent(
+            f"""
         CREATE OR REPLACE FUNCTION keystone_read_only_insert()
           RETURNS trigger AS
         $BODY$
@@ -1026,10 +962,12 @@ def upgrade():
           RAISE EXCEPTION '{error_message}';
         END
         $BODY$ LANGUAGE plpgsql;
-        """)
+        """
+        )
         op.execute(identity_provider_insert_trigger)
 
-        federated_user_insert_trigger = textwrap.dedent("""
+        federated_user_insert_trigger = textwrap.dedent(
+            """
         CREATE OR REPLACE FUNCTION update_federated_user_domain_id()
             RETURNS trigger AS
         $BODY$
@@ -1040,10 +978,12 @@ def upgrade():
             RETURN NULL;
         END
         $BODY$ LANGUAGE plpgsql;
-        """)
+        """
+        )
         op.execute(federated_user_insert_trigger)
 
-        local_user_insert_trigger = textwrap.dedent("""
+        local_user_insert_trigger = textwrap.dedent(
+            """
         CREATE OR REPLACE FUNCTION update_user_domain_id()
             RETURNS trigger AS
         $BODY$
@@ -1053,7 +993,8 @@ def upgrade():
             RETURN NULL;
         END
         $BODY$ LANGUAGE plpgsql;
-        """)
+        """
+        )
         op.execute(local_user_insert_trigger)
 
     # FIXME(stephenfin): Remove these indexes. They're left over from attempts
@@ -1065,9 +1006,7 @@ def upgrade():
         # FIXME(stephenfin): This should be dropped when we add the FK
         # constraint to this column
         op.create_index(
-            'registered_limit_id',
-            'limit',
-            ['registered_limit_id'],
+            'registered_limit_id', 'limit', ['registered_limit_id']
         )
 
         # FIXME(stephenfin): These are leftover from when we removed a FK
