@@ -47,14 +47,16 @@ class Manager(manager.Manager):
     _provides_api = 'federation_api'
 
     def __init__(self):
-        super(Manager, self).__init__(CONF.federation.driver)
+        super().__init__(CONF.federation.driver)
         notifications.register_event_callback(
-            notifications.ACTIONS.internal, notifications.DOMAIN_DELETED,
-            self._cleanup_identity_provider
+            notifications.ACTIONS.internal,
+            notifications.DOMAIN_DELETED,
+            self._cleanup_identity_provider,
         )
 
-    def _cleanup_identity_provider(self, service, resource_type, operation,
-                                   payload):
+    def _cleanup_identity_provider(
+        self, service, resource_type, operation, payload
+    ):
         domain_id = payload['resource_info']
         hints = driver_hints.Hints()
         hints.add_filter('domain_id', domain_id)
@@ -63,10 +65,14 @@ class Manager(manager.Manager):
             try:
                 self.delete_idp(idp['id'])
             except exception.IdentityProviderNotFound:
-                LOG.debug(('Identity Provider %(idpid)s not found when '
-                           'deleting domain contents for %(domainid)s, '
-                           'continuing with cleanup.'),
-                          {'idpid': idp['id'], 'domainid': domain_id})
+                LOG.debug(
+                    (
+                        'Identity Provider %(idpid)s not found when '
+                        'deleting domain contents for %(domainid)s, '
+                        'continuing with cleanup.'
+                    ),
+                    {'idpid': idp['id'], 'domainid': domain_id},
+                )
 
     def create_idp(self, idp_id, idp):
         auto_created_domain = False
@@ -94,9 +100,9 @@ class Manager(manager.Manager):
         # provider removes a federated identity provider resource.
         reason = (
             'The token cache is being invalidated because identity provider '
-            '%(idp_id)s has been deleted. Authorization for federated users '
+            f'{idp_id} has been deleted. Authorization for federated users '
             'will be recalculated and enforced accordingly the next time '
-            'they authenticate or validate a token.' % {'idp_id': idp_id}
+            'they authenticate or validate a token.'
         )
         notifications.invalidate_token_cache_notification(reason)
 
@@ -113,7 +119,7 @@ class Manager(manager.Manager):
             'id': domain_id,
             'name': domain_id,
             'description': desc,
-            'enabled': True
+            'enabled': True,
         }
         PROVIDERS.resource_api.create_domain(domain['id'], domain)
         return domain_id
@@ -137,12 +143,9 @@ class Manager(manager.Manager):
         :rtype: list of dicts
 
         """
+
         def normalize(sp):
-            ref = {
-                'auth_url': sp.auth_url,
-                'id': sp.id,
-                'sp_url': sp.sp_url
-            }
+            ref = {'auth_url': sp.auth_url, 'id': sp.id, 'sp_url': sp.sp_url}
             return ref
 
         service_providers = self.driver.get_enabled_service_providers()
@@ -164,8 +167,11 @@ class Manager(manager.Manager):
 
     def evaluate(self, idp_id, protocol_id, assertion_data):
         mapping = self.get_mapping_from_idp_and_protocol(idp_id, protocol_id)
-        rules = mapping['rules']
-        rule_processor = utils.RuleProcessor(mapping['id'], rules)
+
+        rule_processor = utils.create_attribute_mapping_rules_processor(
+            mapping
+        )
+
         mapped_properties = rule_processor.process(assertion_data)
         return mapped_properties, mapping['id']
 
@@ -176,18 +182,9 @@ class Manager(manager.Manager):
     def delete_protocol(self, idp_id, protocol_id):
         hints = driver_hints.Hints()
         hints.add_filter('protocol_id', protocol_id)
-        shadow_users = PROVIDERS.shadow_users_api.list_federated_users_info(
-            hints)
 
         self.driver.delete_protocol(idp_id, protocol_id)
 
-        for shadow_user in shadow_users:
-            PROVIDERS.identity_api.shadow_federated_user.invalidate(
-                PROVIDERS.identity_api, shadow_user['idp_id'],
-                shadow_user['protocol_id'], shadow_user['unique_id'],
-                shadow_user['display_name'],
-                shadow_user.get('extra', {}).get('email'))
-
     def update_protocol(self, idp_id, protocol_id, protocol):
         self._validate_mapping_exists(protocol['mapping_id'])
         return self.driver.update_protocol(idp_id, protocol_id, protocol)
