@@ -1151,8 +1151,7 @@ class KeystoneLDAPHandler(LDAPHandler):
         if attrlist is not None:
             attrlist = [attr for attr in attrlist if attr is not None]
         LOG.debug(
-            'LDAP search: base=%s scope=%s filterstr=%s '
-            'attrs=%s attrsonly=%s',
+            'LDAP search: base=%s scope=%s filterstr=%s attrs=%s attrsonly=%s',
             base,
             scope,
             filterstr,
@@ -1417,6 +1416,12 @@ class BaseLdap:
         self.auth_pool_conn_lifetime = conf.ldap.auth_pool_connection_lifetime
 
         if self.options_name is not None:
+            self.user_tree_dn = (
+                conf.ldap.user_tree_dn
+                or f'{self.DEFAULT_OU},{conf.ldap.suffix}'
+            )
+            self.user_objectclass = conf.ldap.user_objectclass
+
             self.tree_dn = (
                 getattr(conf.ldap, f'{self.options_name}_tree_dn')
                 or f'{self.DEFAULT_OU},{conf.ldap.suffix}'
@@ -1732,7 +1737,7 @@ class BaseLdap:
         if not attr:
             attr_name = f'{self.options_name}_{self.attribute_options_names[ldap_attr_name]}_attribute'
             raise ValueError(
-                f'"{attr}" is not a valid value for' f' "{attr_name}"'
+                f'"{attr}" is not a valid value for "{attr_name}"'
             )
 
         # consider attr = "cn" and
@@ -1766,9 +1771,7 @@ class BaseLdap:
 
     def _ldap_get(self, object_id, ldap_filter=None):
         query = (
-            '(&({id_attr}={id})'
-            '{filter}'
-            '(objectClass={object_class}))'.format(
+            '(&({id_attr}={id}){filter}(objectClass={object_class}))'.format(
                 id_attr=self.id_attr,
                 id=ldap.filter.escape_filter_chars(str(object_id)),
                 filter=ldap_filter or self.ldap_filter or '',
@@ -1854,9 +1857,14 @@ class BaseLdap:
         return self._filter_ldap_result_by_attr(res, 'name')
 
     def _ldap_get_list(
-        self, search_base, scope, query_params=None, attrlist=None
+        self,
+        search_base,
+        scope,
+        query_params=None,
+        attrlist=None,
+        object_class=None,
     ):
-        query = f'(objectClass={self.object_class})'
+        query = f'(objectClass={object_class or self.object_class})'
         if query_params:
 
             def calc_filter(attrname, value):
