@@ -14,15 +14,48 @@
 
 import abc
 
-import six
-
 from keystone import exception
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ShadowUsersDriverBase(object):
+def federated_objects_to_list(fed_ref):
+    """Create a new reformatted federated object list using the one passed in.
+
+    When returning federated objects with a user we only need the attributes
+    idp_id, protocol_id, and unique_id. Therefore, we pull these elements out
+    of the fed_ref and create a newly formatted list with the needed
+    information. We simply group each federated object's protocol_ids and
+    unique_ids under the corresponding idp_id.
+
+    :returns list: Containing the user's federated objects
+    """
+    if not fed_ref:
+        return []
+
+    fed = {}
+    for fed_dict in fed_ref:
+        fed.setdefault(
+            fed_dict['idp_id'], {'idp_id': fed_dict['idp_id'], 'protocols': []}
+        )['protocols'].append(
+            {
+                'protocol_id': fed_dict['protocol_id'],
+                'unique_id': fed_dict['unique_id'],
+            }
+        )
+
+    return list(fed.values())
+
+
+class ShadowUsersDriverBase(metaclass=abc.ABCMeta):
     """Interface description for an Shadow Users driver."""
 
+    @abc.abstractmethod
+    def create_federated_object(self, fed_dict):
+        """Create a new federated object.
+
+        :param dict federated_dict: Reference to the federated user
+        """
+        raise exception.NotImplemented()
+
     @abc.abstractmethod
     def create_federated_user(self, domain_id, federated_dict, email=None):
         """Create a new user with the federated identity.
@@ -35,6 +68,23 @@ class ShadowUsersDriverBase(object):
         """
         raise exception.NotImplemented()
 
+    def delete_federated_object(self, user_id):
+        """Delete a user's federated objects.
+
+        :param user_id: Unique identifier of the user
+        """
+        raise exception.NotImplemented()
+
+    @abc.abstractmethod
+    def get_federated_objects(self, user_id):
+        """Get all federated objects for a user.
+
+        :param user_id: Unique identifier of the user
+        :returns list: Containing the user's federated objects
+
+        """
+        raise exception.NotImplemented()
+
     @abc.abstractmethod
     def get_federated_user(self, idp_id, protocol_id, unique_id):
         """Return the found user for the federated identity.
@@ -48,8 +98,9 @@ class ShadowUsersDriverBase(object):
         raise exception.NotImplemented()
 
     @abc.abstractmethod
-    def update_federated_user_display_name(self, idp_id, protocol_id,
-                                           unique_id, display_name):
+    def update_federated_user_display_name(
+        self, idp_id, protocol_id, unique_id, display_name
+    ):
         """Update federated user's display name if changed.
 
         :param idp_id: The identity provider ID
