@@ -19,7 +19,6 @@ import keystone.conf
 from keystone import exception
 from keystone import notifications
 
-
 CONF = keystone.conf.CONF
 
 
@@ -37,7 +36,7 @@ class Manager(manager.Manager):
     _POLICY = 'policy'
 
     def __init__(self):
-        super(Manager, self).__init__(CONF.policy.driver)
+        super().__init__(CONF.policy.driver)
 
     def create_policy(self, policy_id, policy, initiator=None):
         ref = self.driver.create_policy(policy_id, policy)
