@@ -14,7 +14,4 @@
 
 from keystone.receipt.providers.fernet.core import Provider
 
-
-__all__ = (
-    "Provider",
-)
+__all__ = ("Provider",)
