@@ -20,23 +20,23 @@ from oslo_utils import timeutils
 import keystone.conf
 from keystone import exception
 
-
 CONF = keystone.conf.CONF
 
 
 def revoked_before_cutoff_time():
     expire_delta = datetime.timedelta(
-        seconds=CONF.token.expiration + CONF.revoke.expiration_buffer)
+        seconds=CONF.token.expiration + CONF.revoke.expiration_buffer
+    )
     oldest = timeutils.utcnow() - expire_delta
     return oldest
 
 
-class RevokeDriverBase(object, metaclass=abc.ABCMeta):
+class RevokeDriverBase(metaclass=abc.ABCMeta):
     """Interface for recording and reporting revocation events."""
 
     @abc.abstractmethod
     def list_events(self, last_fetch=None, token=None):
-        """return the revocation events, as a list of objects.
+        """Return the revocation events, as a list of objects.
 
         :param last_fetch:   Time of last fetch.  Return all events newer.
         :param token: dictionary of values from a token, normalized for
@@ -52,7 +52,7 @@ class RevokeDriverBase(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def revoke(self, event):
-        """register a revocation event.
+        """Register a revocation event.
 
         :param event: An instance of
             keystone.revoke.model.RevocationEvent
