@@ -17,13 +17,7 @@ import flask
 import oslo_i18n
 from oslo_log import log
 from oslo_middleware import healthcheck
-
-try:
-    # werkzeug 0.15.x
-    from werkzeug.middleware import dispatcher as wsgi_dispatcher
-except ImportError:
-    # werkzeug 0.14.x
-    import werkzeug.wsgi as wsgi_dispatcher
+from werkzeug.middleware import dispatcher
 
 from keystone.api import auth
 from keystone.api import credentials
@@ -238,7 +232,7 @@ def application_factory(name='public'):
     # Use the simple form of the dispatch middleware, no extra logic needed
     # for legacy dispatching. This is to mount /healthcheck at a consistent
     # place
-    app.wsgi_app = wsgi_dispatcher.DispatcherMiddleware(
+    app.wsgi_app = dispatcher.DispatcherMiddleware(
         app.wsgi_app, {'/healthcheck': hc_app}
     )
     return app
