@@ -15,13 +15,7 @@ import os
 
 from oslo_log import log
 import stevedore
-
-try:
-    # werkzeug 0.15.x
-    from werkzeug.middleware import proxy_fix
-except ImportError:
-    # werkzeug 0.14.x
-    from werkzeug.contrib import fixers as proxy_fix
+from werkzeug.middleware import proxy_fix
 
 from keystone.common import profiler
 import keystone.conf
