@@ -29,17 +29,15 @@ from oslo_log.fixture import logging_error as log_fixture
 from oslo_log import log as logging
 from oslotest import base
 
-from keystone.common import sql
-from keystone.common.sql import upgrades
-import keystone.conf
-from keystone.tests.unit import ksfixtures
-
 # We need to import all of these so the tables are registered. It would be
 # easier if these were all in a central location :(
 import keystone.application_credential.backends.sql  # noqa: F401
 import keystone.assignment.backends.sql  # noqa: F401
 import keystone.assignment.role_backends.sql_model  # noqa: F401
 import keystone.catalog.backends.sql  # noqa: F401
+from keystone.common import sql
+from keystone.common.sql import upgrades
+import keystone.conf
 import keystone.credential.backends.sql  # noqa: F401
 import keystone.endpoint_policy.backends.sql  # noqa: F401
 import keystone.federation.backends.sql  # noqa: F401
@@ -51,6 +49,7 @@ import keystone.policy.backends.sql  # noqa: F401
 import keystone.resource.backends.sql_model  # noqa: F401
 import keystone.resource.config_backends.sql  # noqa: F401
 import keystone.revoke.backends.sql  # noqa: F401
+from keystone.tests.unit import ksfixtures
 import keystone.trust.backends.sql  # noqa: F401
 
 CONF = keystone.conf.CONF
@@ -84,8 +83,9 @@ class KeystoneModelsMigrationsSync(test_migrations.ModelsMigrationsSync):
         # Override keystone's context manager to be oslo.db's global context
         # manager.
         sql.core._TESTING_USE_GLOBAL_CONTEXT_MANAGER = True
-        self.addCleanup(setattr,
-                        sql.core, '_TESTING_USE_GLOBAL_CONTEXT_MANAGER', False)
+        self.addCleanup(
+            setattr, sql.core, '_TESTING_USE_GLOBAL_CONTEXT_MANAGER', False
+        )
         self.addCleanup(sql.cleanup)
 
     def db_sync(self, engine):
