@@ -25,6 +25,7 @@ import oslo_messaging
 from oslo_utils import timeutils
 from pycadf import cadftaxonomy
 from pycadf import cadftype
+from pycadf import event as cadfevent
 from pycadf import eventfactory
 from pycadf import resource as cadfresource
 
@@ -299,6 +300,7 @@ class BaseNotificationTest(test_v3.RestfulTestCase):
             target,
             event_type,
             reason=None,
+            attachments=None,
             **kwargs,
         ):
             service_security = cadftaxonomy.SERVICE_SECURITY
@@ -313,6 +315,10 @@ class BaseNotificationTest(test_v3.RestfulTestCase):
                 observer=cadfresource.Resource(typeURI=service_security),
             )
 
+            attachments = attachments if attachments is not None else []
+            for attachment_val in attachments:
+                event.add_attachment(attachment_val)
+
             for key, value in kwargs.items():
                 setattr(event, key, value)
 
@@ -356,7 +362,13 @@ class BaseNotificationTest(test_v3.RestfulTestCase):
             self.assertEqual(actor_operation, note['actor_operation'])
 
     def _assert_last_audit(
-        self, resource_id, operation, resource_type, target_uri, reason=None
+        self,
+        resource_id,
+        operation,
+        resource_type,
+        target_uri,
+        reason=None,
+        attachments=None,
     ):
         # NOTE(stevemar): If 'cadf' format is not used, then simply
         # return since this assertion is not valid.
@@ -384,6 +396,15 @@ class BaseNotificationTest(test_v3.RestfulTestCase):
                 reason['reasonType'], payload['reason']['reasonType']
             )
         self.assertTrue(audit['send_notification_called'])
+        if attachments is None:
+            self.assertNotIn(cadfevent.EVENT_KEYNAME_ATTACHMENTS, payload)
+        else:
+            self.assertIn(cadfevent.EVENT_KEYNAME_ATTACHMENTS, payload)
+            for attachment_val in attachments:
+                self.assertIn(
+                    attachment_val,
+                    payload.get(cadfevent.EVENT_KEYNAME_ATTACHMENTS),
+                )
 
     def _assert_initiator_data_is_set(self, operation, resource_type, typeURI):
         self.assertGreater(len(self._audits), 0)
@@ -1142,6 +1163,131 @@ class CADFNotificationsForPCIDSSEvents(BaseNotificationTest):
             reason=expected_reason,
         )
 
+    def test_valid_password_not_hashed_by_default(self):
+        password = uuid.uuid4().hex
+        user_ref = unit.new_user_ref(
+            domain_id=self.domain_id, password=password
+        )
+        user_ref = PROVIDERS.identity_api.create_user(user_ref)
+
+        with mock.patch(
+            'keystone.common.password_hashing.generate_partial_password_hash'
+        ) as mocked:
+            with self.make_request():
+                PROVIDERS.identity_api.authenticate(user_ref['id'], password)
+            mocked.assert_not_called()
+
+        self._assert_last_audit(
+            None,
+            'authenticate',
+            None,
+            cadftaxonomy.ACCOUNT_USER,
+            attachments=None,
+        )
+
+    def test_invalid_password_not_hashed_by_default(self):
+        password = uuid.uuid4().hex
+        invalid_password = 'invalid_' + password
+        user_ref = unit.new_user_ref(
+            domain_id=self.domain_id, password=password
+        )
+        user_ref = PROVIDERS.identity_api.create_user(user_ref)
+
+        with mock.patch(
+            'keystone.common.password_hashing.generate_partial_password_hash'
+        ) as mocked:
+            with self.make_request():
+                self.assertRaises(
+                    AssertionError,
+                    PROVIDERS.identity_api.authenticate,
+                    user_id=user_ref['id'],
+                    password=invalid_password,
+                )
+            mocked.assert_not_called()
+
+        self._assert_last_audit(
+            None,
+            'authenticate',
+            None,
+            cadftaxonomy.ACCOUNT_USER,
+            attachments=None,
+        )
+
+    def test_valid_password_hash_not_included_when_report_in_event(self):
+        password = uuid.uuid4().hex
+        user_ref = unit.new_user_ref(
+            domain_id=self.domain_id, password=password
+        )
+        user_ref = PROVIDERS.identity_api.create_user(user_ref)
+
+        conf = self.useFixture(config_fixture.Config(CONF))
+        conf.config(
+            group='security_compliance', report_invalid_password_hash='event'
+        )
+        conf.config(
+            group='security_compliance',
+            invalid_password_hash_secret_key='secret_key',
+        )
+        with mock.patch(
+            'keystone.common.password_hashing.generate_partial_password_hash'
+        ) as mocked:
+            with self.make_request():
+                PROVIDERS.identity_api.authenticate(user_ref['id'], password)
+            mocked.assert_not_called()
+
+        self._assert_last_audit(
+            None,
+            'authenticate',
+            None,
+            cadftaxonomy.ACCOUNT_USER,
+            attachments=None,
+        )
+
+    def test_invalid_password_hash_included_when_report_in_event(self):
+        password = uuid.uuid4().hex
+        invalid_password = 'invalid_' + password
+        user_ref = unit.new_user_ref(
+            domain_id=self.domain_id, password=password
+        )
+        user_ref = PROVIDERS.identity_api.create_user(user_ref)
+
+        conf = self.useFixture(config_fixture.Config(CONF))
+        conf.config(
+            group='security_compliance', report_invalid_password_hash='event'
+        )
+        conf.config(
+            group='security_compliance',
+            invalid_password_hash_secret_key='secret_key',
+        )
+        hashed_invalid_password = 'hashed_' + invalid_password
+        with mock.patch(
+            'keystone.common.password_hashing.generate_partial_password_hash',
+            return_value=hashed_invalid_password,
+        ) as mocked:
+            with self.make_request():
+                self.assertRaises(
+                    AssertionError,
+                    PROVIDERS.identity_api.authenticate,
+                    user_id=user_ref['id'],
+                    password=invalid_password,
+                )
+
+            mocked.assert_called_once()
+
+        self._assert_last_audit(
+            None,
+            'authenticate',
+            None,
+            cadftaxonomy.ACCOUNT_USER,
+            attachments=[
+                {
+                    'content': hashed_invalid_password,
+                    'name': "partial_password_hash",
+                    'typeURI': "mime:text/plain",
+                }
+            ],
+        )
+
 
 class CADFNotificationsForEntities(NotificationsForEntities):
     def setUp(self):
@@ -1420,7 +1566,7 @@ class CadfNotificationsWrapperTestCase(test_v3.RestfulTestCase):
                     'typeURI': 'service/security/account/user',
                     'host': {'address': 'localhost'},
                     'id': 'openstack:0a90d95d-582c-4efb-9cbc-e2ca7ca9c341',
-                    'username': u'admin'
+                    'name': 'admin'
                 },
                 'target': {
                     'typeURI': 'service/security/account/user',
@@ -1475,6 +1621,7 @@ class CadfNotificationsWrapperTestCase(test_v3.RestfulTestCase):
         self.assertEqual(len(self._notifications), 1)
         note = self._notifications.pop()
         initiator = note['initiator']
+        self.assertEqual(self.user['name'], initiator.name)
         self.assertEqual(self.user['name'], initiator.username)
 
     def test_v3_authenticate_user_name_and_domain_id(self):
