@@ -10,13 +10,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from unittest import mock
 import uuid
 
 import fixtures
 import flask
 from flask import blueprints
 import flask_restful
-import mock
 from oslo_policy import policy
 
 from keystone.common import authorization
@@ -27,12 +27,10 @@ from keystone import exception
 from keystone.tests import unit
 from keystone.tests.unit import rest
 
-
 PROVIDER_APIS = provider_api.ProviderAPIs
 
 
 class TestRBACEnforcer(unit.TestCase):
-
     def test_enforcer_shared_state(self):
         enforcer = rbac_enforcer.enforcer.RBACEnforcer()
         enforcer2 = rbac_enforcer.enforcer.RBACEnforcer()
@@ -52,9 +50,8 @@ class TestRBACEnforcer(unit.TestCase):
 
 
 class _TestRBACEnforcerBase(rest.RestfulTestCase):
-
     def setUp(self):
-        super(_TestRBACEnforcerBase, self).setUp()
+        super().setUp()
         self._setup_enforcer_object()
         self._setup_dynamic_flask_blueprint_api()
         self._setup_flask_restful_api()
@@ -67,20 +64,26 @@ class _TestRBACEnforcerBase(rest.RestfulTestCase):
             rules = self._testing_policy_rules()
             enforcer.register_defaults(rules)
 
-        self.useFixture(fixtures.MockPatchObject(
-            self.enforcer, 'register_rules', register_new_rules))
+        self.useFixture(
+            fixtures.MockPatchObject(
+                self.enforcer, 'register_rules', register_new_rules
+            )
+        )
 
         # Set the possible actions to our limited list
         original_actions = rbac_enforcer.enforcer._POSSIBLE_TARGET_ACTIONS
-        rbac_enforcer.enforcer._POSSIBLE_TARGET_ACTIONS = frozenset([
-            rule.name for rule in self._testing_policy_rules()])
+        rbac_enforcer.enforcer._POSSIBLE_TARGET_ACTIONS = frozenset(
+            [rule.name for rule in self._testing_policy_rules()]
+        )
 
         # RESET the FrozenSet of possible target actions to the original
         # value
-        self.addCleanup(setattr,
-                        rbac_enforcer.enforcer,
-                        '_POSSIBLE_TARGET_ACTIONS',
-                        original_actions)
+        self.addCleanup(
+            setattr,
+            rbac_enforcer.enforcer,
+            '_POSSIBLE_TARGET_ACTIONS',
+            original_actions,
+        )
 
         # Force a reset on the enforcer to load up new policy rules.
         self.enforcer._reset()
@@ -88,17 +91,23 @@ class _TestRBACEnforcerBase(rest.RestfulTestCase):
     def _setup_dynamic_flask_blueprint_api(self):
         # Create a dynamic flask blueprint with a known prefix
         api = uuid.uuid4().hex
-        url_prefix = '/_%s_TEST' % api
+        url_prefix = f'/_{api}_TEST'
         blueprint = blueprints.Blueprint(api, __name__, url_prefix=url_prefix)
         self.url_prefix = url_prefix
         self.flask_blueprint = blueprint
         self.cleanup_instance('flask_blueprint', 'url_prefix')
 
-    def _setup_flask_restful_api(self):
-        self.restful_api_url_prefix = '/_%s_TEST' % uuid.uuid4().hex
-        self.restful_api = flask_restful.Api(self.public_app.app,
-                                             self.restful_api_url_prefix)
+    def _driver_simulation_get_method(self, argument_id):
         user = self.user_req_admin
+        return {'id': argument_id, 'value': 'TEST', 'owner_id': user['id']}
+
+    def _setup_flask_restful_api(self):
+        self.restful_api_url_prefix = f'/_{uuid.uuid4().hex}_TEST'
+        self.restful_api = flask_restful.Api(
+            self.public_app.app, self.restful_api_url_prefix
+        )
+
+        driver_simulation_method = self._driver_simulation_get_method
 
         # Very Basic Restful Resource
         class RestfulResource(flask_restful.Resource):
@@ -108,26 +117,26 @@ class _TestRBACEnforcerBase(rest.RestfulTestCase):
                 return self._list_arguments()
 
             def _get_argument(self, argument_id):
-                return {'argument': {
-                        'id': argument_id,
-                        'value': 'TEST',
-                        'owner_id': user['id']}}
+                return {'argument': driver_simulation_method(argument_id)}
 
             def _list_arguments(self):
                 return {'arguments': []}
 
         self.restful_api_resource = RestfulResource
         self.restful_api.add_resource(
-            RestfulResource, '/argument/<string:argument_id>', '/argument')
-        self.cleanup_instance('restful_api', 'restful_resource',
-                              'restful_api_url_prefix')
+            RestfulResource, '/argument/<string:argument_id>', '/argument'
+        )
+        self.cleanup_instance(
+            'restful_api', 'restful_resource', 'restful_api_url_prefix'
+        )
 
     def _register_blueprint_to_app(self):
         # TODO(morgan): remove the need for webtest, but for now just unwrap
         # by one layer. Once everything is converted to flask, we can fix
         # the tests to eliminate "webtest".
         self.public_app.app.register_blueprint(
-            self.flask_blueprint, url_prefix=self.url_prefix)
+            self.flask_blueprint, url_prefix=self.url_prefix
+        )
 
     def _auth_json(self):
         return {
@@ -138,17 +147,11 @@ class _TestRBACEnforcerBase(rest.RestfulTestCase):
                         'user': {
                             'name': self.user_req_admin['name'],
                             'password': self.user_req_admin['password'],
-                            'domain': {
-                                'id': self.user_req_admin['domain_id']
-                            }
+                            'domain': {'id': self.user_req_admin['domain_id']},
                         }
-                    }
+                    },
                 },
-                'scope': {
-                    'project': {
-                        'id': self.tenant_service['id']
-                    }
-                }
+                'scope': {'project': {'id': self.project_service['id']}},
             }
         }
 
@@ -175,9 +178,7 @@ class _TestRBACEnforcerBase(rest.RestfulTestCase):
                 scope_types=['project'],
             ),
             policy.RuleDefault(
-                name='example:allowed',
-                check_str='',
-                scope_types=['project'],
+                name='example:allowed', check_str='', scope_types=['project']
             ),
             policy.RuleDefault(
                 name='example:denied',
@@ -189,44 +190,44 @@ class _TestRBACEnforcerBase(rest.RestfulTestCase):
 
 
 class TestRBACEnforcerRestAdminAuthToken(_TestRBACEnforcerBase):
-
     def config_overrides(self):
-        super(TestRBACEnforcerRestAdminAuthToken, self).config_overrides()
+        super().config_overrides()
         self.config_fixture.config(admin_token='ADMIN')
 
     def test_enforcer_is_admin_check_with_token(self):
         # Admin-shared token passed and valid, "is_admin" should be true.
         with self.test_client() as c:
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={authorization.AUTH_TOKEN_HEADER: 'ADMIN'})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={authorization.AUTH_TOKEN_HEADER: 'ADMIN'},
+            )
             self.assertTrue(self.enforcer._shared_admin_auth_token_set())
 
     def test_enforcer_is_admin_check_without_token(self):
         with self.test_client() as c:
             # Admin-shared token passed and invalid, "is_admin" should be false
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={authorization.AUTH_TOKEN_HEADER: 'BOGUS'})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={authorization.AUTH_TOKEN_HEADER: 'BOGUS'},
+            )
             self.assertFalse(self.enforcer._shared_admin_auth_token_set())
 
             # Admin-shared token not passed, "is_admin" should be false
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex))
+            c.get(f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}')
             self.assertFalse(self.enforcer._shared_admin_auth_token_set())
 
     def test_enforce_call_is_admin(self):
         with self.test_client() as c:
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={authorization.AUTH_TOKEN_HEADER: 'ADMIN'})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={authorization.AUTH_TOKEN_HEADER: 'ADMIN'},
+            )
             with mock.patch.object(self.enforcer, '_enforce') as mock_method:
                 self.enforcer.enforce_call(action='example:allowed')
                 mock_method.assert_not_called()
 
 
 class TestRBACEnforcerRest(_TestRBACEnforcerBase):
-
     def test_extract_subject_token_target_data(self):
         path = '/v3/auth/tokens'
         body = self._auth_json()
@@ -236,21 +237,30 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
                 path,
                 json=body,
                 follow_redirects=True,
-                expected_status_code=201)
+                expected_status_code=201,
+            )
 
             token_id = r.headers['X-Subject-Token']
 
-            c.get('/v3', headers={'X-Auth-Token': token_id,
-                                  'X-Subject-Token': token_id})
+            c.get(
+                '/v3',
+                headers={
+                    'X-Auth-Token': token_id,
+                    'X-Subject-Token': token_id,
+                },
+            )
             token = PROVIDER_APIS.token_provider_api.validate_token(token_id)
             subj_token_data = (
-                self.enforcer._extract_subject_token_target_data())
+                self.enforcer._extract_subject_token_target_data()
+            )
             subj_token_data = subj_token_data['token']
             self.assertEqual(token.user_id, subj_token_data['user_id'])
             self.assertIn('user', subj_token_data)
             self.assertIn('domain', subj_token_data['user'])
-            self.assertEqual(token.user_domain['id'],
-                             subj_token_data['user']['domain']['id'])
+            self.assertEqual(
+                token.user_domain['id'],
+                subj_token_data['user']['domain']['id'],
+            )
 
     def test_extract_filter_data(self):
         # Test that we are extracting useful filter data from the
@@ -260,7 +270,7 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
 
         path = uuid.uuid4().hex
 
-        @self.flask_blueprint.route('/%s' % path)
+        @self.flask_blueprint.route(f'/{path}')
         def return_nothing_interesting():
             return 'OK', 200
 
@@ -273,15 +283,13 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             # Populate the query-string with two params, one that should
             # exist and one that should not in the resulting policy
             # dict.
-            qs = '%(expected)s=EXPECTED&%(unexpected)s=UNEXPECTED' % {
-                'expected': expected_param,
-                'unexpected': unexpected_param
-            }
+            qs = f'{expected_param}=EXPECTED&{unexpected_param}=UNEXPECTED'
             # Perform the get with the query-string
-            c.get('%(path)s?%(qs)s' % {'path': get_path, 'qs': qs})
+            c.get(f'{get_path}?{qs}')
             # Extract the filter values.
             extracted_filter = self.enforcer._extract_filter_values(
-                [expected_param])
+                [expected_param]
+            )
             # Unexpected param is not in the extracted values
             # Expected param is in the extracted values
             # Expected param has the expected value
@@ -294,8 +302,7 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         # from the environ as expected. The only way to really test is an
         # instance check.
         with self.test_client() as c:
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex))
+            c.get(f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}')
             oslo_req_context = self.enforcer._get_oslo_req_context()
             self.assertIsInstance(oslo_req_context, context.RequestContext)
 
@@ -306,18 +313,21 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         with self.test_client() as c:
             r = c.post(token_path, json=auth_json, expected_status_code=201)
             token_id = r.headers.get('X-Subject-Token')
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={'X-Auth-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={'X-Auth-Token': token_id},
+            )
             self.enforcer._assert_is_authenticated()
             c.get('/', expected_status_code=300)
-            self.assertRaises(exception.Unauthorized,
-                              self.enforcer._assert_is_authenticated)
+            self.assertRaises(
+                exception.Unauthorized, self.enforcer._assert_is_authenticated
+            )
             oslo_ctx = self.enforcer._get_oslo_req_context()
             # Set authenticated to a false value that is not None
             oslo_ctx.authenticated = False
-            self.assertRaises(exception.Unauthorized,
-                              self.enforcer._assert_is_authenticated)
+            self.assertRaises(
+                exception.Unauthorized, self.enforcer._assert_is_authenticated
+            )
 
     def test_extract_policy_check_credentials(self):
         # Make sure extracting the creds is the same as what is in the request
@@ -327,13 +337,15 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         with self.test_client() as c:
             r = c.post(token_path, json=auth_json, expected_status_code=201)
             token_id = r.headers.get('X-Subject-Token')
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={'X-Auth-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={'X-Auth-Token': token_id},
+            )
             extracted_creds = self.enforcer._extract_policy_check_credentials()
             self.assertEqual(
                 flask.request.environ.get(authorization.AUTH_CONTEXT_ENV),
-                extracted_creds)
+                extracted_creds,
+            )
 
     def test_extract_member_target_data_inferred(self):
         # NOTE(morgan): Setup the "resource" object with a 'member_name' attr
@@ -344,19 +356,21 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         # with current @protected (ease of use). For most cases the target
         # should be explicitly passed to .enforce_call, but for ease of
         # converting / use, the automatic population of data has been added.
-        self.restful_api_resource.member_name = 'argument'
-        member_from_driver = self.restful_api_resource.get
+        self.restful_api_resource.member_key = 'argument'
+        member_from_driver = self._driver_simulation_get_method
         self.restful_api_resource.get_member_from_driver = member_from_driver
 
         argument_id = uuid.uuid4().hex
 
         with self.test_client() as c:
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      argument_id))
+            c.get(f'{self.restful_api_url_prefix}/argument/{argument_id}')
             extracted = self.enforcer._extract_member_target_data(
-                member_target_type=None, member_target=None)
-            self.assertDictEqual(extracted['target'],
-                                 self.restful_api_resource().get(argument_id))
+                member_target_type=None, member_target=None
+            )
+            self.assertDictEqual(
+                extracted['target'],
+                self.restful_api_resource().get(argument_id),
+            )
 
     def test_view_args_populated_in_policy_dict(self):
         # Setup the "resource" object and make a call that has view arguments
@@ -364,13 +378,15 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         # that properly checks (substitutes in) a value that is not in "target"
         # path but in the main policy dict path.
 
-        def _enforce_mock_func(credentials, action, target,
-                               do_raise=True):
+        def _enforce_mock_func(credentials, action, target, do_raise=True):
             if 'argument_id' not in target:
                 raise exception.ForbiddenAction(action=action)
 
-        self.useFixture(fixtures.MockPatchObject(
-            self.enforcer, '_enforce', _enforce_mock_func))
+        self.useFixture(
+            fixtures.MockPatchObject(
+                self.enforcer, '_enforce', _enforce_mock_func
+            )
+        )
 
         argument_id = uuid.uuid4().hex
 
@@ -384,21 +400,27 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
                 path,
                 json=body,
                 follow_redirects=True,
-                expected_status_code=201)
+                expected_status_code=201,
+            )
 
             token_id = r.headers['X-Subject-Token']
 
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      argument_id),
-                  headers={'X-Auth-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{argument_id}',
+                headers={'X-Auth-Token': token_id},
+            )
 
             # Use any valid policy as _enforce is mockpatched out
             self.enforcer.enforce_call(action='example:allowed')
-            c.get('%s/argument' % self.restful_api_url_prefix,
-                  headers={'X-Auth-Token': token_id})
-            self.assertRaises(exception.ForbiddenAction,
-                              self.enforcer.enforce_call,
-                              action='example:allowed')
+            c.get(
+                f'{self.restful_api_url_prefix}/argument',
+                headers={'X-Auth-Token': token_id},
+            )
+            self.assertRaises(
+                exception.ForbiddenAction,
+                self.enforcer.enforce_call,
+                action='example:allowed',
+            )
 
     def test_extract_member_target_data_supplied_target(self):
         # Test extract member target data with member_target and
@@ -406,17 +428,69 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         member_type = uuid.uuid4().hex
         member_target = {uuid.uuid4().hex: {uuid.uuid4().hex}}
         extracted = self.enforcer._extract_member_target_data(
-            member_target_type=member_type, member_target=member_target)
-        self.assertDictEqual({'target': {member_type: member_target}},
-                             extracted)
+            member_target_type=member_type, member_target=member_target
+        )
+        self.assertDictEqual(
+            {'target': {member_type: member_target}}, extracted
+        )
 
     def test_extract_member_target_data_bad_input(self):
         # Test Extract Member Target Data with only "member_target" and only
         # "member_target_type" and ensure empty dict is returned.
-        self.assertEqual({}, self.enforcer._extract_member_target_data(
-            member_target=None, member_target_type=uuid.uuid4().hex))
-        self.assertEqual({}, self.enforcer._extract_member_target_data(
-            member_target={}, member_target_type=None))
+        self.assertEqual(
+            {},
+            self.enforcer._extract_member_target_data(
+                member_target=None, member_target_type=uuid.uuid4().hex
+            ),
+        )
+        self.assertEqual(
+            {},
+            self.enforcer._extract_member_target_data(
+                member_target={}, member_target_type=None
+            ),
+        )
+
+    def test_call_build_enforcement_target(self):
+        assertIn = self.assertIn
+        assertEq = self.assertEqual
+        ref_uuid = uuid.uuid4().hex
+
+        def _enforce_mock_func(credentials, action, target, do_raise=True):
+            assertIn('target.domain.id', target)
+            assertEq(target['target.domain.id'], ref_uuid)
+
+        def _build_enforcement_target():
+            return {'domain': {'id': ref_uuid}}
+
+        self.useFixture(
+            fixtures.MockPatchObject(
+                self.enforcer, '_enforce', _enforce_mock_func
+            )
+        )
+
+        argument_id = uuid.uuid4().hex
+
+        with self.test_client() as c:
+            path = '/v3/auth/tokens'
+            body = self._auth_json()
+
+            r = c.post(
+                path,
+                json=body,
+                follow_redirects=True,
+                expected_status_code=201,
+            )
+
+            token_id = r.headers['X-Subject-Token']
+
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{argument_id}',
+                headers={'X-Auth-Token': token_id},
+            )
+            self.enforcer.enforce_call(
+                action='example:allowed',
+                build_target=_build_enforcement_target,
+            )
 
     def test_policy_enforcer_action_decorator(self):
         # Create a method that has an action pre-registered
@@ -430,9 +504,10 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         self._register_blueprint_to_app()
 
         with self.test_client() as c:
-            c.get('%s' % self.url_prefix)
+            c.get(f'{self.url_prefix}')
             self.assertEqual(
-                action, getattr(flask.g, self.enforcer.ACTION_STORE_ATTR))
+                action, getattr(flask.g, self.enforcer.ACTION_STORE_ATTR)
+            )
 
     def test_policy_enforcer_action_invalid_action_decorator(self):
         # If the "action" is not a registered policy enforcement point, check
@@ -450,27 +525,33 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         self.assertRaises(ValueError, _decorator_fails)
 
     def test_enforce_call_invalid_action(self):
-        self.assertRaises(exception.Forbidden,
-                          self.enforcer.enforce_call,
-                          action=uuid.uuid4().hex)
+        self.assertRaises(
+            exception.Forbidden,
+            self.enforcer.enforce_call,
+            action=uuid.uuid4().hex,
+        )
 
     def test_enforce_call_not_is_authenticated(self):
         with self.test_client() as c:
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex))
+            c.get(f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}')
             # Patch the enforcer to return an empty oslo context.
-            with mock.patch.object(self.enforcer, '_get_oslo_req_context',
-                                   return_value=None):
+            with mock.patch.object(
+                self.enforcer, '_get_oslo_req_context', return_value=None
+            ):
                 self.assertRaises(
                     exception.Unauthorized,
-                    self.enforcer.enforce_call, action='example:allowed')
+                    self.enforcer.enforce_call,
+                    action='example:allowed',
+                )
 
             # Explicitly set "authenticated" on the context to false.
             ctx = self.enforcer._get_oslo_req_context()
             ctx.authenticated = False
             self.assertRaises(
                 exception.Unauthorized,
-                self.enforcer.enforce_call, action='example:allowed')
+                self.enforcer.enforce_call,
+                action='example:allowed',
+            )
 
     def test_enforce_call_explicit_target_attr(self):
         token_path = '/v3/auth/tokens'
@@ -483,19 +564,24 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             #
             # TODO(morgan): confirm if subject-token-processing can/should
             # occur in this form without causing issues.
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={'X-Auth-Token': token_id,
-                           'X-Subject-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={
+                    'X-Auth-Token': token_id,
+                    'X-Subject-Token': token_id,
+                },
+            )
             target = {'myuser': {'id': self.user_req_admin['id']}}
-            self.enforcer.enforce_call(action='example:target',
-                                       target_attr=target)
+            self.enforcer.enforce_call(
+                action='example:target', target_attr=target
+            )
             # Ensure extracting the subject-token data is not happening.
             self.assertRaises(
                 exception.ForbiddenAction,
                 self.enforcer.enforce_call,
                 action='example:subject_token',
-                target_attr=target)
+                target_attr=target,
+            )
 
     def test_enforce_call_with_subject_token_data(self):
         token_path = '/v3/auth/tokens'
@@ -506,10 +592,13 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             # Check that the enforcer passes if user_id and subject token
             # user_id are the same. example:deprecated should also pass
             # since it is open enforcement.
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={'X-Auth-Token': token_id,
-                           'X-Subject-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={
+                    'X-Auth-Token': token_id,
+                    'X-Subject-Token': token_id,
+                },
+            )
             self.enforcer.enforce_call(action='example:subject_token')
 
     def test_enforce_call_with_member_target_type_and_member_target(self):
@@ -521,15 +610,20 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             # check the enforcer properly handles passed in member_target_type
             # and member_target. This form still extracts data from the subject
             # token.
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={'X-Auth-Token': token_id,
-                           'X-Subject-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={
+                    'X-Auth-Token': token_id,
+                    'X-Subject-Token': token_id,
+                },
+            )
             target_type = 'myuser'
             target = {'id': self.user_req_admin['id']}
-            self.enforcer.enforce_call(action='example:target',
-                                       member_target_type=target_type,
-                                       member_target=target)
+            self.enforcer.enforce_call(
+                action='example:target',
+                member_target_type=target_type,
+                member_target=target,
+            )
             # Ensure we're still extracting the subject-token data
             self.enforcer.enforce_call(action='example:subject_token')
 
@@ -537,8 +631,8 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
         # Check that inferred "get" works as expected for the member target
 
         # setup the restful resource for an inferred "get"
-        self.restful_api_resource.member_name = 'argument'
-        member_from_driver = self.restful_api_resource.get
+        self.restful_api_resource.member_key = 'argument'
+        member_from_driver = self._driver_simulation_get_method
         self.restful_api_resource.get_member_from_driver = member_from_driver
 
         token_path = '/v3/auth/tokens'
@@ -548,10 +642,13 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             token_id = r.headers.get('X-Subject-Token')
             # check the enforcer properly handles inferred member data get
             # This form still extracts data from the subject token.
-            c.get('%s/argument/%s' % (self.restful_api_url_prefix,
-                                      uuid.uuid4().hex),
-                  headers={'X-Auth-Token': token_id,
-                           'X-Subject-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={
+                    'X-Auth-Token': token_id,
+                    'X-Subject-Token': token_id,
+                },
+            )
             self.enforcer.enforce_call(action='example:inferred_member_data')
             # Ensure we're still extracting the subject-token data
             self.enforcer.enforce_call(action='example:subject_token')
@@ -564,37 +661,47 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             token_id = r.headers.get('X-Subject-Token')
             # Check that the enforcer passes if a filter is supplied *and*
             # the filter name is passed to enforce_call
-            c.get('%s/argument/%s?user=%s' % (
-                self.restful_api_url_prefix, uuid.uuid4().hex,
-                self.user_req_admin['id']),
-                headers={'X-Auth-Token': token_id})
-            self.enforcer.enforce_call(action='example:with_filter',
-                                       filters=['user'])
+            c.get(
+                '{}/argument/{}?user={}'.format(
+                    self.restful_api_url_prefix,
+                    uuid.uuid4().hex,
+                    self.user_req_admin['id'],
+                ),
+                headers={'X-Auth-Token': token_id},
+            )
+            self.enforcer.enforce_call(
+                action='example:with_filter', filters=['user']
+            )
 
             # With No Filters passed into enforce_call
             self.assertRaises(
                 exception.ForbiddenAction,
                 self.enforcer.enforce_call,
-                action='example:with_filter')
+                action='example:with_filter',
+            )
 
             # With No Filters in the PATH
-            c.get('%s/argument/%s' % (
-                self.restful_api_url_prefix, uuid.uuid4().hex),
-                headers={'X-Auth-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={'X-Auth-Token': token_id},
+            )
             self.assertRaises(
                 exception.ForbiddenAction,
                 self.enforcer.enforce_call,
                 action='example:with_filter',
-                filters=['user'])
+                filters=['user'],
+            )
 
             # With no filters in the path and no filters passed to enforce_call
-            c.get('%s/argument/%s' % (
-                self.restful_api_url_prefix, uuid.uuid4().hex),
-                headers={'X-Auth-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={'X-Auth-Token': token_id},
+            )
             self.assertRaises(
                 exception.ForbiddenAction,
                 self.enforcer.enforce_call,
-                action='example:with_filter')
+                action='example:with_filter',
+            )
 
     def test_enforce_call_with_pre_instantiated_enforcer(self):
         token_path = '/v3/auth/tokens'
@@ -605,15 +712,19 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             token_id = r.headers.get('X-Subject-Token')
             # Check the enforcer behaves as expected with a pre-instantiated
             # enforcer passed into .enforce_call()
-            c.get('%s/argument/%s' % (
-                self.restful_api_url_prefix, uuid.uuid4().hex),
-                headers={'X-Auth-Token': token_id})
-            self.enforcer.enforce_call(action='example:allowed',
-                                       enforcer=enforcer)
-            self.assertRaises(exception.ForbiddenAction,
-                              self.enforcer.enforce_call,
-                              action='example:denied',
-                              enforcer=enforcer)
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={'X-Auth-Token': token_id},
+            )
+            self.enforcer.enforce_call(
+                action='example:allowed', enforcer=enforcer
+            )
+            self.assertRaises(
+                exception.ForbiddenAction,
+                self.enforcer.enforce_call,
+                action='example:denied',
+                enforcer=enforcer,
+            )
 
     def test_enforce_call_sets_enforcement_attr(self):
         # Ensure calls to enforce_call set the value on flask.g that indicates
@@ -625,33 +736,43 @@ class TestRBACEnforcerRest(_TestRBACEnforcerBase):
             # app to have access to g (without an explicit app-context push)
             r = c.post(token_path, json=auth_json, expected_status_code=201)
             token_id = r.headers.get('X-Subject-Token')
-            c.get('%s/argument/%s' % (
-                self.restful_api_url_prefix, uuid.uuid4().hex),
-                headers={'X-Auth-Token': token_id})
+            c.get(
+                f'{self.restful_api_url_prefix}/argument/{uuid.uuid4().hex}',
+                headers={'X-Auth-Token': token_id},
+            )
 
             # Ensure the attribute is not set
             self.assertFalse(
                 hasattr(
-                    flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR)
+                    flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR
+                )
             )
             # Set the value to false, like the resource have done automatically
             setattr(
-                flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR, False)
+                flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR, False
+            )
             # Enforce
             self.enforcer.enforce_call(action='example:allowed')
             # Verify the attribute has been set to true.
             self.assertEqual(
-                getattr(flask.g,
-                        rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR),
-                True)
+                getattr(
+                    flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR
+                ),
+                True,
+            )
             # Reset Attribute and check that attribute is still set even if
             # enforcement results in forbidden.
             setattr(
-                flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR, False)
-            self.assertRaises(exception.ForbiddenAction,
-                              self.enforcer.enforce_call,
-                              action='example:denied')
+                flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR, False
+            )
+            self.assertRaises(
+                exception.ForbiddenAction,
+                self.enforcer.enforce_call,
+                action='example:denied',
+            )
             self.assertEqual(
-                getattr(flask.g,
-                        rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR),
-                True)
+                getattr(
+                    flask.g, rbac_enforcer.enforcer._ENFORCEMENT_CHECK_ATTR
+                ),
+                True,
+            )
