@@ -10,10 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import fixtures
 import hashlib
 import uuid
 
+import fixtures
 from oslo_log import log
 
 from keystone.common import fernet_utils
@@ -25,14 +25,14 @@ from keystone.tests.unit.ksfixtures import database
 
 class TestFernetCredentialProvider(unit.TestCase):
     def setUp(self):
-        super(TestFernetCredentialProvider, self).setUp()
+        super().setUp()
         self.provider = credential_fernet.Provider()
         self.useFixture(database.Database())
         self.useFixture(
             ksfixtures.KeyRepository(
                 self.config_fixture,
                 'credential',
-                credential_fernet.MAX_ACTIVE_KEYS
+                credential_fernet.MAX_ACTIVE_KEYS,
             )
         )
 
@@ -48,7 +48,7 @@ class TestFernetCredentialProvider(unit.TestCase):
 
 class TestFernetCredentialProviderWithNullKey(unit.TestCase):
     def setUp(self):
-        super(TestFernetCredentialProviderWithNullKey, self).setUp()
+        super().setUp()
         self.provider = credential_fernet.Provider()
         self.useFixture(database.Database())
         # Only do this to set the key_repository location in configuration. To
@@ -59,7 +59,7 @@ class TestFernetCredentialProviderWithNullKey(unit.TestCase):
         # default.
         self.config_fixture.config(
             group='credential',
-            key_repository=self.useFixture(fixtures.TempDir()).path
+            key_repository=self.useFixture(fixtures.TempDir()).path,
         )
 
     def test_encryption_with_null_key(self):
