@@ -23,33 +23,34 @@ from keystone.tests.unit.ksfixtures import database
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class ShadowUsersTests(unit.TestCase,
-                       test_backend.ShadowUsersBackendTests,
-                       test_core.ShadowUsersCoreTests):
+class ShadowUsersTests(
+    unit.TestCase,
+    test_backend.ShadowUsersBackendTests,
+    test_core.ShadowUsersCoreTests,
+):
     def setUp(self):
-        super(ShadowUsersTests, self).setUp()
+        super().setUp()
         self.useFixture(database.Database())
         self.load_backends()
         PROVIDERS.resource_api.create_domain(
-            default_fixtures.ROOT_DOMAIN['id'], default_fixtures.ROOT_DOMAIN)
+            default_fixtures.ROOT_DOMAIN['id'], default_fixtures.ROOT_DOMAIN
+        )
         self.idp = {
             'id': uuid.uuid4().hex,
             'enabled': True,
-            'description': uuid.uuid4().hex
-        }
-        self.mapping = {
-            'id': uuid.uuid4().hex,
+            'description': uuid.uuid4().hex,
         }
+        self.mapping = {'id': uuid.uuid4().hex}
         self.protocol = {
             'id': uuid.uuid4().hex,
             'idp_id': self.idp['id'],
-            'mapping_id': self.mapping['id']
+            'mapping_id': self.mapping['id'],
         }
         self.federated_user = {
             'idp_id': self.idp['id'],
             'protocol_id': self.protocol['id'],
             'unique_id': uuid.uuid4().hex,
-            'display_name': uuid.uuid4().hex
+            'display_name': uuid.uuid4().hex,
         }
         self.email = uuid.uuid4().hex
         PROVIDERS.federation_api.create_idp(self.idp['id'], self.idp)
@@ -57,30 +58,35 @@ class ShadowUsersTests(unit.TestCase,
             self.mapping['id'], self.mapping
         )
         PROVIDERS.federation_api.create_protocol(
-            self.idp['id'], self.protocol['id'], self.protocol)
-        self.domain_id = (
-            PROVIDERS.federation_api.get_idp(self.idp['id'])['domain_id'])
+            self.idp['id'], self.protocol['id'], self.protocol
+        )
+        self.domain_id = PROVIDERS.federation_api.get_idp(self.idp['id'])[
+            'domain_id'
+        ]
 
 
 class TestUserWithFederatedUser(ShadowUsersTests):
-
     def setUp(self):
-        super(TestUserWithFederatedUser, self).setUp()
+        super().setUp()
         self.useFixture(database.Database())
         self.load_backends()
 
     def assertFederatedDictsEqual(self, fed_dict, fed_object):
         self.assertEqual(fed_dict['idp_id'], fed_object['idp_id'])
-        self.assertEqual(fed_dict['protocol_id'],
-                         fed_object['protocols'][0]['protocol_id'])
-        self.assertEqual(fed_dict['unique_id'],
-                         fed_object['protocols'][0]['unique_id'])
+        self.assertEqual(
+            fed_dict['protocol_id'], fed_object['protocols'][0]['protocol_id']
+        )
+        self.assertEqual(
+            fed_dict['unique_id'], fed_object['protocols'][0]['unique_id']
+        )
 
     def test_get_user_when_user_has_federated_object(self):
-        fed_dict = unit.new_federated_user_ref(idp_id=self.idp['id'],
-                                               protocol_id=self.protocol['id'])
+        fed_dict = unit.new_federated_user_ref(
+            idp_id=self.idp['id'], protocol_id=self.protocol['id']
+        )
         user = self.shadow_users_api.create_federated_user(
-            self.domain_id, fed_dict)
+            self.domain_id, fed_dict
+        )
 
         # test that the user returns a federated object and that there is only
         # one returned
@@ -96,23 +102,20 @@ class TestUserWithFederatedUser(ShadowUsersTests):
             {
                 'idp_id': 'fakeidp',
                 'protocols': [
-                    {
-                        'protocol_id': 'nonexistent',
-                        'unique_id': 'unknown'
-                    }
-                ]
+                    {'protocol_id': 'nonexistent', 'unique_id': 'unknown'}
+                ],
             }
         ]
         # Check validation works by throwing a federated object with
         # invalid idp_id, protocol_id inside the user passed to create_user.
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.create_user,
-                          baduser)
+        self.assertRaises(
+            exception.ValidationError, self.identity_api.create_user, baduser
+        )
 
         baduser['federated'][0]['idp_id'] = self.idp['id']
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.create_user,
-                          baduser)
+        self.assertRaises(
+            exception.ValidationError, self.identity_api.create_user, baduser
+        )
 
     def test_create_user_with_federated_attributes(self):
         # Create the schema of a federated attribute being passed in with a
@@ -125,19 +128,21 @@ class TestUserWithFederatedUser(ShadowUsersTests):
                 'protocols': [
                     {
                         'protocol_id': self.protocol['id'],
-                        'unique_id': unique_id
+                        'unique_id': unique_id,
                     }
-                ]
+                ],
             }
         ]
 
         # Test that there are no current federated_users that match our users
         # federated object and create the user
-        self.assertRaises(exception.UserNotFound,
-                          self.shadow_users_api.get_federated_user,
-                          self.idp['id'],
-                          self.protocol['id'],
-                          unique_id)
+        self.assertRaises(
+            exception.UserNotFound,
+            self.shadow_users_api.get_federated_user,
+            self.idp['id'],
+            self.protocol['id'],
+            unique_id,
+        )
 
         ref = self.identity_api.create_user(user)
 
@@ -145,9 +150,8 @@ class TestUserWithFederatedUser(ShadowUsersTests):
         self.assertEqual(user['name'], ref['name'])
         self.assertEqual(user['federated'], ref['federated'])
         fed_user = self.shadow_users_api.get_federated_user(
-            self.idp['id'],
-            self.protocol['id'],
-            unique_id)
+            self.idp['id'], self.protocol['id'], unique_id
+        )
         self.assertIsNotNone(fed_user)
 
     def test_update_user_with_invalid_idp_and_protocol_fails(self):
@@ -156,34 +160,33 @@ class TestUserWithFederatedUser(ShadowUsersTests):
             {
                 'idp_id': 'fakeidp',
                 'protocols': [
-                    {
-                        'protocol_id': 'nonexistent',
-                        'unique_id': 'unknown'
-                    }
-                ]
+                    {'protocol_id': 'nonexistent', 'unique_id': 'unknown'}
+                ],
             }
         ]
         # Check validation works by throwing a federated object with
         # invalid idp_id, protocol_id inside the user passed to create_user.
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.create_user,
-                          baduser)
+        self.assertRaises(
+            exception.ValidationError, self.identity_api.create_user, baduser
+        )
 
         baduser['federated'][0]['idp_id'] = self.idp['id']
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.create_user,
-                          baduser)
+        self.assertRaises(
+            exception.ValidationError, self.identity_api.create_user, baduser
+        )
 
     def test_update_user_with_federated_attributes(self):
         user = self.shadow_users_api.create_federated_user(
-            self.domain_id, self.federated_user)
+            self.domain_id, self.federated_user
+        )
         user = self.identity_api.get_user(user['id'])
 
         # Test that update user can return a federated object with the user as
         # a response if the user has any
         user = self.identity_api.update_user(user['id'], user)
-        self.assertFederatedDictsEqual(self.federated_user,
-                                       user['federated'][0])
+        self.assertFederatedDictsEqual(
+            self.federated_user, user['federated'][0]
+        )
 
         # Test that update user can replace a users federated objects if added
         # in the request and that its response is that new federated objects
@@ -193,9 +196,9 @@ class TestUserWithFederatedUser(ShadowUsersTests):
                 'protocols': [
                     {
                         'protocol_id': self.protocol['id'],
-                        'unique_id': uuid.uuid4().hex
+                        'unique_id': uuid.uuid4().hex,
                     }
-                ]
+                ],
             }
         ]
         user['federated'] = new_fed
