@@ -12,6 +12,7 @@
 
 import datetime
 import http.client
+import unittest
 import uuid
 
 from oslo_utils import timeutils
@@ -63,7 +64,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -89,7 +90,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -111,7 +112,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles, secret=secret)
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -123,7 +124,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body()
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -146,7 +147,9 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             c.post(
-                '/v3/users/%s/application_credentials' % wrong_user['id'],
+                '/v3/users/{}/application_credentials'.format(
+                    wrong_user['id']
+                ),
                 json=app_cred_body,
                 expected_status_code=http.client.FORBIDDEN,
                 headers={'X-Auth-Token': token},
@@ -158,7 +161,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.BAD_REQUEST,
                 headers={'X-Auth-Token': token},
@@ -172,7 +175,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles, expires=expires)
             token = self.get_scoped_token()
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -185,7 +188,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles, expires=expires)
             token = self.get_scoped_token()
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.BAD_REQUEST,
                 headers={'X-Auth-Token': token},
@@ -198,7 +201,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles, expires=expires)
             token = self.get_scoped_token()
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.BAD_REQUEST,
                 headers={'X-Auth-Token': token},
@@ -210,7 +213,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body_1 = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             app_cred_1 = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body_1,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -225,7 +228,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body_2 = self._app_cred_body(roles=roles)
             token = token_data.headers['x-subject-token']
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body_2,
                 expected_status_code=http.client.FORBIDDEN,
                 headers={'X-Auth-Token': token},
@@ -264,7 +267,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             # only the roles from the trust token should be allowed, even if
             # the user has the role assigned on the project
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 headers={'X-Auth-Token': trust_token},
                 json=app_cred,
                 expected_status_code=http.client.BAD_REQUEST,
@@ -277,7 +280,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body_1['application_credential']['unrestricted'] = True
             token = self.get_scoped_token()
             app_cred_1 = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body_1,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -291,7 +294,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             )
             app_cred_body_2 = self._app_cred_body(roles=roles)
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body_2,
                 expected_status_code=http.client.CREATED,
                 headers={
@@ -302,11 +305,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
     def test_create_application_credential_with_access_rules(self):
         roles = [{'id': self.role_id}]
         access_rules = [
-            {
-                'path': '/v3/projects',
-                'method': 'POST',
-                'service': 'identity',
-            }
+            {'path': '/v3/projects', 'method': 'POST', 'service': 'identity'}
         ]
         app_cred_body = self._app_cred_body(
             roles=roles, access_rules=access_rules
@@ -314,7 +313,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 headers={'X-Auth-Token': token},
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
@@ -326,7 +325,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             access_rule_id = resp_access_rules[0].pop('id')
             self.assertEqual(access_rules[0], resp_access_rules[0])
             resp = c.get(
-                '/v3/users/%s/access_rules' % self.user_id,
+                f'/v3/users/{self.user_id}/access_rules',
                 headers={'X-Auth-Token': token},
             )
             resp_access_rule = resp.json['access_rules'][0]
@@ -334,8 +333,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             resp_access_rule.pop('links')
             self.assertEqual(access_rules[0], resp_access_rule)
             resp = c.get(
-                '/v3/users/%s/access_rules/%s'
-                % (self.user_id, access_rule_id),
+                f'/v3/users/{self.user_id}/access_rules/{access_rule_id}',
                 headers={'X-Auth-Token': token},
             )
             resp_access_rule = resp.json['access_rule']
@@ -344,30 +342,23 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             self.assertEqual(access_rules[0], resp_access_rule)
             # can't delete an access rule in use
             c.delete(
-                '/v3/users/%s/access_rules/%s'
-                % (self.user_id, access_rule_id),
+                f'/v3/users/{self.user_id}/access_rules/{access_rule_id}',
                 headers={'X-Auth-Token': token},
                 expected_status_code=http.client.FORBIDDEN,
             )
             c.delete(
-                '/v3/users/%s/application_credentials/%s'
-                % (self.user_id, app_cred_id),
+                f'/v3/users/{self.user_id}/application_credentials/{app_cred_id}',
                 headers={'X-Auth-Token': token},
             )
             c.delete(
-                '/v3/users/%s/access_rules/%s'
-                % (self.user_id, access_rule_id),
+                f'/v3/users/{self.user_id}/access_rules/{access_rule_id}',
                 headers={'X-Auth-Token': token},
             )
 
     def test_create_application_credential_with_duplicate_access_rule(self):
         roles = [{'id': self.role_id}]
         access_rules = [
-            {
-                'path': '/v3/projects',
-                'method': 'POST',
-                'service': 'identity',
-            }
+            {'path': '/v3/projects', 'method': 'POST', 'service': 'identity'}
         ]
         app_cred_body_1 = self._app_cred_body(
             roles=roles, access_rules=access_rules
@@ -375,7 +366,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 headers={'X-Auth-Token': token},
                 json=app_cred_body_1,
                 expected_status_code=http.client.CREATED,
@@ -391,7 +382,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 headers={'X-Auth-Token': token},
                 json=app_cred_body_2,
                 expected_status_code=http.client.CREATED,
@@ -402,11 +393,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
     def test_create_application_credential_with_access_rule_by_id(self):
         roles = [{'id': self.role_id}]
         access_rules = [
-            {
-                'path': '/v3/projects',
-                'method': 'POST',
-                'service': 'identity',
-            }
+            {'path': '/v3/projects', 'method': 'POST', 'service': 'identity'}
         ]
         app_cred_body_1 = self._app_cred_body(
             roles=roles, access_rules=access_rules
@@ -414,7 +401,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 headers={'X-Auth-Token': token},
                 json=app_cred_body_1,
                 expected_status_code=http.client.CREATED,
@@ -432,7 +419,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 headers={'X-Auth-Token': token},
                 json=app_cred_body_2,
                 expected_status_code=http.client.CREATED,
@@ -444,7 +431,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.get(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
             )
@@ -452,13 +439,13 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             roles = [{'id': self.role_id}]
             app_cred_body = self._app_cred_body(roles=roles)
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
             )
             resp = c.get(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
             )
@@ -469,13 +456,13 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             )
             app_cred_body['application_credential']['name'] = 'two'
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
             )
             resp = c.get(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
             )
@@ -493,7 +480,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             resp = c.get(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
             )
@@ -501,19 +488,19 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             roles = [{'id': second_role['id']}]
             app_cred_body = self._app_cred_body(roles=roles)
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
             )
             resp = c.get(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
             )
             PROVIDERS.role_api.delete_role(second_role['id'])
             resp = c.get(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
             )
@@ -525,9 +512,8 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             token = self.get_scoped_token()
             name = app_cred_body['application_credential']['name']
             search_path = (
-                '/v3/users/%(user_id)s/application_credentials?'
-                'name=%(name)s'
-            ) % {'user_id': self.user_id, 'name': name}
+                f'/v3/users/{self.user_id}/application_credentials?name={name}'
+            )
             resp = c.get(
                 search_path,
                 expected_status_code=http.client.OK,
@@ -535,7 +521,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             )
             self.assertEqual([], resp.json['application_credentials'])
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -552,7 +538,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             )
             app_cred_body['application_credential']['name'] = 'two'
             c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -573,15 +559,14 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
             )
             app_cred_id = resp.json['application_credential']['id']
             c.head(
-                '/v3%s'
-                % MEMBER_PATH_FMT
+                f'/v3{MEMBER_PATH_FMT}'
                 % {'user_id': self.user_id, 'app_cred_id': app_cred_id},
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
@@ -589,8 +574,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             expected_response = resp.json
             expected_response['application_credential'].pop('secret')
             resp = c.get(
-                '/v3%s'
-                % MEMBER_PATH_FMT
+                f'/v3{MEMBER_PATH_FMT}'
                 % {'user_id': self.user_id, 'app_cred_id': app_cred_id},
                 expected_status_code=http.client.OK,
                 headers={'X-Auth-Token': token},
@@ -601,15 +585,13 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             c.head(
-                '/v3%s'
-                % MEMBER_PATH_FMT
+                f'/v3{MEMBER_PATH_FMT}'
                 % {'user_id': self.user_id, 'app_cred_id': uuid.uuid4().hex},
                 expected_status_code=http.client.NOT_FOUND,
                 headers={'X-Auth-Token': token},
             )
             c.get(
-                '/v3%s'
-                % MEMBER_PATH_FMT
+                f'/v3{MEMBER_PATH_FMT}'
                 % {'user_id': self.user_id, 'app_cred_id': uuid.uuid4().hex},
                 expected_status_code=http.client.NOT_FOUND,
                 headers={'X-Auth-Token': token},
@@ -621,15 +603,14 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
             )
             app_cred_id = resp.json['application_credential']['id']
             c.delete(
-                '/v3%s'
-                % MEMBER_PATH_FMT
+                f'/v3{MEMBER_PATH_FMT}'
                 % {'user_id': self.user_id, 'app_cred_id': app_cred_id},
                 expected_status_code=http.client.NO_CONTENT,
                 headers={'X-Auth-Token': token},
@@ -639,8 +620,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         with self.test_client() as c:
             token = self.get_scoped_token()
             c.delete(
-                '/v3%s'
-                % MEMBER_PATH_FMT
+                f'/v3{MEMBER_PATH_FMT}'
                 % {'user_id': self.user_id, 'app_cred_id': uuid.uuid4().hex},
                 expected_status_code=http.client.NOT_FOUND,
                 headers={'X-Auth-Token': token},
@@ -652,7 +632,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             app_cred = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -664,16 +644,10 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             token_data = self.v3_create_token(
                 auth_data, expected_status=http.client.CREATED
             )
-            member_path = (
-                '/v3%s'
-                % MEMBER_PATH_FMT
-                % {
-                    'user_id': self.user_id,
-                    'app_cred_id': app_cred.json['application_credential'][
-                        'id'
-                    ],
-                }
-            )
+            member_path = f'/v3{MEMBER_PATH_FMT}' % {
+                'user_id': self.user_id,
+                'app_cred_id': app_cred.json['application_credential']['id'],
+            }
             token = token_data.headers['x-subject-token']
             c.delete(
                 member_path,
@@ -689,7 +663,7 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body['application_credential']['unrestricted'] = True
             token = self.get_scoped_token()
             app_cred = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
@@ -701,16 +675,10 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             token_data = self.v3_create_token(
                 auth_data, expected_status=http.client.CREATED
             )
-            member_path = (
-                '/v3%s'
-                % MEMBER_PATH_FMT
-                % {
-                    'user_id': self.user_id,
-                    'app_cred_id': app_cred.json['application_credential'][
-                        'id'
-                    ],
-                }
-            )
+            member_path = f'/v3{MEMBER_PATH_FMT}' % {
+                'user_id': self.user_id,
+                'app_cred_id': app_cred.json['application_credential']['id'],
+            }
             c.delete(
                 member_path,
                 json=app_cred_body,
@@ -726,27 +694,138 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_body = self._app_cred_body(roles=roles)
             token = self.get_scoped_token()
             resp = c.post(
-                '/v3/users/%s/application_credentials' % self.user_id,
+                f'/v3/users/{self.user_id}/application_credentials',
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
                 headers={'X-Auth-Token': token},
             )
             # Application credentials are immutable
-            app_cred_body['application_credential'][
-                'description'
-            ] = "New Things"
+            app_cred_body['application_credential']['description'] = (
+                "New Things"
+            )
             app_cred_id = resp.json['application_credential']['id']
             # NOTE(morgan): when the whole test case is converted to using
             # flask test_client, this extra v3 prefix will
             # need to be rolled into the base MEMBER_PATH_FMT
-            member_path = (
-                '/v3%s'
-                % MEMBER_PATH_FMT
-                % {'user_id': self.user_id, 'app_cred_id': app_cred_id}
-            )
+            member_path = f'/v3{MEMBER_PATH_FMT}' % {
+                'user_id': self.user_id,
+                'app_cred_id': app_cred_id,
+            }
             c.patch(
                 member_path,
                 json=app_cred_body,
                 expected_status_code=http.client.METHOD_NOT_ALLOWED,
                 headers={'X-Auth-Token': token},
             )
+
+    def test_list_access_rules(self):
+        access_rules: list[dict[str, str]] = [
+            {"service": "foo", "method": "GET", "path": "/bar"}
+        ]
+        with self.test_client() as c:
+            roles = [{'id': self.role_id}]
+            app_cred_body = self._app_cred_body(
+                roles=roles, access_rules=access_rules
+            )
+            token = self.get_scoped_token()
+            c.post(
+                f"/v3/users/{self.user_id}/application_credentials",
+                json=app_cred_body,
+                expected_status_code=http.client.CREATED,
+                headers={"X-Auth-Token": token},
+            )
+            # Invoke GET access_rules and trigger internal validation
+            r = c.get(
+                f"/v3/users/{self.user_id}/access_rules",
+                expected_status_code=http.client.OK,
+                headers={"X-Auth-Token": token},
+            )
+            ar = r.json["access_rules"]
+            self.assertEqual(access_rules[0]["method"], ar[0]["method"])
+
+    # TODO(stephenfin): This will pass once we increase strictness of the query
+    # string validation
+    @unittest.expectedFailure
+    def test_list_access_rules_invalid_qs(self):
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            # Invoke GET access_rules with unsupported query parameters and
+            # trigger internal validation
+            c.get(
+                f"/v3/users/{self.user_id}/access_rules?user_id=foo",
+                expected_status_code=http.client.BAD_REQUEST,
+                headers={"X-Auth-Token": token},
+            )
+
+    def test_show_access_rule(self):
+        access_rules: list[dict[str, str]] = [
+            {"service": "foo", "method": "GET", "path": "/bar"}
+        ]
+        with self.test_client() as c:
+            roles = [{'id': self.role_id}]
+            app_cred_body = self._app_cred_body(
+                roles=roles, access_rules=access_rules
+            )
+            token = self.get_scoped_token()
+            resp = c.post(
+                f"/v3/users/{self.user_id}/application_credentials",
+                json=app_cred_body,
+                expected_status_code=http.client.CREATED,
+                headers={"X-Auth-Token": token},
+            )
+            access_rule_id = resp.json["application_credential"][
+                "access_rules"
+            ][0]["id"]
+            # Invoke GET access_rules/{id} and trigger internal validation
+            c.get(
+                f"/v3/users/{self.user_id}/access_rules/{access_rule_id}",
+                expected_status_code=http.client.OK,
+                headers={"X-Auth-Token": token},
+            )
+
+    # TODO(stephenfin): This will pass once we increase strictness of the query
+    # string validation
+    @unittest.expectedFailure
+    def test_show_access_rule_invalid_qs(self):
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            # Invoke GET access_rules/{id} with unsupported query parameters and
+            # trigger internal validation
+            c.get(
+                f"/v3/users/{self.user_id}/access_rules/{access_rule_id}"
+                "?foo=bar",
+                expected_status_code=http.client.BAD_REQUEST,
+                headers={"X-Auth-Token": token},
+            )
+
+    def test_delete_access_rule(self):
+        access_rules: list[dict[str, str]] = [
+            {"service": "foo", "method": "GET", "path": "/bar"}
+        ]
+        with self.test_client() as c:
+            roles = [{'id': self.role_id}]
+            app_cred_body = self._app_cred_body(
+                roles=roles, access_rules=access_rules
+            )
+            token = self.get_scoped_token()
+            resp = c.post(
+                f"/v3/users/{self.user_id}/application_credentials",
+                json=app_cred_body,
+                expected_status_code=http.client.CREATED,
+                headers={"X-Auth-Token": token},
+            )
+            app_cred: dict = resp.json["application_credential"]
+            access_rule_id = app_cred["access_rules"][0]["id"]
+            c.delete(
+                f"/v3/users/{self.user_id}/application_credentials"
+                f"/{app_cred['id']}",
+                json=app_cred_body,
+                expected_status_code=http.client.NO_CONTENT,
+                headers={"X-Auth-Token": token},
+            )
+            # Invoke GET access_rules/{id} and trigger internal validation
+            c.delete(
+                f"/v3/users/{self.user_id}/access_rules/{access_rule_id}",
+                expected_status_code=http.client.NO_CONTENT,
+                headers={"X-Auth-Token": token},
+            )
