@@ -11,20 +11,22 @@
 # under the License.
 
 import datetime
-import mock
+import http.client
+from unittest import mock
 import uuid
 
 import freezegun
 from oslo_db import exception as oslo_db_exception
 from oslo_utils import timeutils
-import six
-from six.moves import http_client
 from testtools import matchers
 
+from keystone.common import provider_api
 from keystone.common import utils
 from keystone.models import revoke_model
 from keystone.tests.unit import test_v3
 
+PROVIDERS = provider_api.ProviderAPIs
+
 
 def _future_time_string():
     expire_delta = datetime.timedelta(seconds=1000)
@@ -33,12 +35,9 @@ def _future_time_string():
 
 
 class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
-
     JSON_HOME_DATA = {
-        'http://docs.openstack.org/api/openstack-identity/3/ext/OS-REVOKE/1.0/'
-        'rel/events': {
-            'href': '/OS-REVOKE/events',
-        },
+        'https://docs.openstack.org/api/openstack-identity/3/ext/OS-REVOKE/1.0'
+        '/rel/events': {'href': '/OS-REVOKE/events'}
     }
 
     def test_get_empty_list(self):
@@ -53,19 +52,20 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
     def assertReportedEventMatchesRecorded(self, event, sample, before_time):
         after_time = timeutils.utcnow()
         event_issued_before = timeutils.normalize_time(
-            timeutils.parse_isotime(event['issued_before']))
+            timeutils.parse_isotime(event['issued_before'])
+        )
         self.assertLessEqual(
-            before_time, event_issued_before,
-            'invalid event issued_before time; %s is not later than %s.' % (
-                utils.isotime(event_issued_before, subsecond=True),
-                utils.isotime(before_time, subsecond=True)))
+            before_time,
+            event_issued_before,
+            f'invalid event issued_before time; {utils.isotime(event_issued_before, subsecond=True)} is not later than {utils.isotime(before_time, subsecond=True)}.',
+        )
         self.assertLessEqual(
-            event_issued_before, after_time,
-            'invalid event issued_before time; %s is not earlier than %s.' % (
-                utils.isotime(event_issued_before, subsecond=True),
-                utils.isotime(after_time, subsecond=True)))
-        del (event['issued_before'])
-        del (event['revoked_at'])
+            event_issued_before,
+            after_time,
+            f'invalid event issued_before time; {utils.isotime(event_issued_before, subsecond=True)} is not earlier than {utils.isotime(after_time, subsecond=True)}.',
+        )
+        del event['issued_before']
+        del event['revoked_at']
         self.assertEqual(sample, event)
 
     def test_revoked_list_self_url(self):
@@ -77,9 +77,9 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
     def test_revoked_token_in_list(self):
         audit_id = uuid.uuid4().hex
         sample = self._blank_event()
-        sample['audit_id'] = six.text_type(audit_id)
+        sample['audit_id'] = str(audit_id)
         before_time = timeutils.utcnow().replace(microsecond=0)
-        self.revoke_api.revoke_by_audit_id(audit_id)
+        PROVIDERS.revoke_api.revoke_by_audit_id(audit_id)
         resp = self.get('/OS-REVOKE/events')
         events = resp.json_body['events']
         self.assertEqual(1, len(events))
@@ -87,11 +87,12 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
 
     def test_disabled_project_in_list(self):
         project_id = uuid.uuid4().hex
-        sample = dict()
-        sample['project_id'] = six.text_type(project_id)
+        sample = {}
+        sample['project_id'] = str(project_id)
         before_time = timeutils.utcnow().replace(microsecond=0)
-        self.revoke_api.revoke(
-            revoke_model.RevokeEvent(project_id=project_id))
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(project_id=project_id)
+        )
 
         resp = self.get('/OS-REVOKE/events')
         events = resp.json_body['events']
@@ -100,11 +101,12 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
 
     def test_disabled_domain_in_list(self):
         domain_id = uuid.uuid4().hex
-        sample = dict()
-        sample['domain_id'] = six.text_type(domain_id)
+        sample = {}
+        sample['domain_id'] = str(domain_id)
         before_time = timeutils.utcnow().replace(microsecond=0)
-        self.revoke_api.revoke(
-            revoke_model.RevokeEvent(domain_id=domain_id))
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(domain_id=domain_id)
+        )
 
         resp = self.get('/OS-REVOKE/events')
         events = resp.json_body['events']
@@ -112,8 +114,10 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
         self.assertReportedEventMatchesRecorded(events[0], sample, before_time)
 
     def test_list_since_invalid(self):
-        self.get('/OS-REVOKE/events?since=blah',
-                 expected_status=http_client.BAD_REQUEST)
+        self.get(
+            '/OS-REVOKE/events?since=blah',
+            expected_status=http.client.BAD_REQUEST,
+        )
 
     def test_list_since_valid(self):
         resp = self.get('/OS-REVOKE/events?since=2013-02-27T18:30:59.999999Z')
@@ -122,27 +126,29 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
 
     def test_since_future_time_no_events(self):
         domain_id = uuid.uuid4().hex
-        sample = dict()
-        sample['domain_id'] = six.text_type(domain_id)
+        sample = {}
+        sample['domain_id'] = str(domain_id)
 
-        self.revoke_api.revoke(
-            revoke_model.RevokeEvent(domain_id=domain_id))
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(domain_id=domain_id)
+        )
 
         resp = self.get('/OS-REVOKE/events')
         events = resp.json_body['events']
         self.assertEqual(1, len(events))
 
-        resp = self.get('/OS-REVOKE/events?since=%s' % _future_time_string())
+        resp = self.get(f'/OS-REVOKE/events?since={_future_time_string()}')
         events = resp.json_body['events']
         self.assertEqual([], events)
 
     def test_revoked_at_in_list(self):
-        time = datetime.datetime.utcnow()
+        time = timeutils.utcnow()
         with freezegun.freeze_time(time) as frozen_datetime:
             revoked_at = timeutils.utcnow()
             # Given or not, `revoked_at` will always be set in the backend.
-            self.revoke_api.revoke(
-                revoke_model.RevokeEvent(revoked_at=revoked_at))
+            PROVIDERS.revoke_api.revoke(
+                revoke_model.RevokeEvent(revoked_at=revoked_at)
+            )
 
             frozen_datetime.tick(delta=datetime.timedelta(seconds=1))
 
@@ -150,14 +156,15 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
             events = resp.json_body['events']
             self.assertThat(events, matchers.HasLength(1))
             # Strip off the microseconds from `revoked_at`.
-            self.assertTimestampEqual(utils.isotime(revoked_at),
-                                      events[0]['revoked_at'])
+            self.assertTimestampEqual(
+                utils.isotime(revoked_at), events[0]['revoked_at']
+            )
 
     def test_access_token_id_not_in_event(self):
         ref = {'description': uuid.uuid4().hex}
         resp = self.post('/OS-OAUTH1/consumers', body={'consumer': ref})
         consumer_id = resp.result['consumer']['id']
-        self.oauth_api.delete_consumer(consumer_id)
+        PROVIDERS.oauth_api.delete_consumer(consumer_id)
 
         resp = self.get('/OS-REVOKE/events')
         events = resp.json_body['events']
@@ -169,13 +176,14 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
         self.assertNotIn('OS-OAUTH1:access_token_id', event)
 
     def test_retries_on_deadlock(self):
-        patcher = mock.patch('sqlalchemy.orm.query.Query.delete',
-                             autospec=True)
+        patcher = mock.patch(
+            'sqlalchemy.orm.query.Query.delete', autospec=True
+        )
 
         # NOTE(mnikolaenko): raise 2 deadlocks and back to normal work of
         # method. Two attempts is enough to check that retry decorator works.
         # Otherwise it will take very much time to pass this test
-        class FakeDeadlock(object):
+        class FakeDeadlock:
             def __init__(self, mock_patcher):
                 self.deadlock_count = 2
                 self.mock_patcher = mock_patcher
@@ -194,8 +202,9 @@ class OSRevokeTests(test_v3.RestfulTestCase, test_v3.JsonHomeTestMixin):
         sql_delete_mock.side_effect = side_effect
 
         try:
-            self.revoke_api.revoke(revoke_model.RevokeEvent(
-                user_id=uuid.uuid4().hex))
+            PROVIDERS.revoke_api.revoke(
+                revoke_model.RevokeEvent(user_id=uuid.uuid4().hex)
+            )
         finally:
             if side_effect.patched:
                 patcher.stop()
