@@ -27,7 +27,6 @@ import keystone.conf
 from keystone import exception
 from keystone.i18n import _
 
-
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
@@ -37,7 +36,7 @@ TIMESTAMP_START = 1
 TIMESTAMP_END = 9
 
 
-class TokenFormatter(object):
+class TokenFormatter:
     """Packs and unpacks payloads into tokens for transport."""
 
     @property
@@ -56,7 +55,7 @@ class TokenFormatter(object):
         fernet_utils = utils.FernetUtils(
             CONF.fernet_tokens.key_repository,
             CONF.fernet_tokens.max_active_keys,
-            'fernet_tokens'
+            'fernet_tokens',
         )
         keys = fernet_utils.load_keys()
 
@@ -89,7 +88,8 @@ class TokenFormatter(object):
             return self.crypto.decrypt(token.encode('utf-8'))
         except fernet.InvalidToken:
             raise exception.ValidationError(
-                _('Could not recognize Fernet token'))
+                _('Could not recognize Fernet token')
+            )
 
     @classmethod
     def restore_padding(cls, token):
@@ -129,21 +129,47 @@ class TokenFormatter(object):
         timestamp_int = struct.unpack(">Q", timestamp_bytes)[0]
 
         # and with an integer, it's trivial to produce a datetime object
-        issued_at = datetime.datetime.utcfromtimestamp(timestamp_int)
+        issued_at = datetime.datetime.fromtimestamp(
+            timestamp_int, datetime.timezone.utc
+        ).replace(tzinfo=None)
 
         return issued_at
 
-    def create_token(self, user_id, expires_at, audit_ids, payload_class,
-                     methods=None, system=None, domain_id=None,
-                     project_id=None, trust_id=None, federated_group_ids=None,
-                     identity_provider_id=None, protocol_id=None,
-                     access_token_id=None, app_cred_id=None):
+    def create_token(
+        self,
+        user_id,
+        expires_at,
+        audit_ids,
+        payload_class,
+        methods=None,
+        system=None,
+        domain_id=None,
+        project_id=None,
+        trust_id=None,
+        federated_group_ids=None,
+        identity_provider_id=None,
+        protocol_id=None,
+        access_token_id=None,
+        app_cred_id=None,
+        thumbprint=None,
+    ):
         """Given a set of payload attributes, generate a Fernet token."""
         version = payload_class.version
         payload = payload_class.assemble(
-            user_id, methods, system, project_id, domain_id, expires_at,
-            audit_ids, trust_id, federated_group_ids, identity_provider_id,
-            protocol_id, access_token_id, app_cred_id
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
         )
 
         versioned_payload = (version,) + payload
@@ -156,10 +182,11 @@ class TokenFormatter(object):
         # characters. Even though Keystone isn't storing a Fernet token
         # anywhere, we can't say it isn't being stored somewhere else with
         # those kind of backend constraints.
-        if len(token) > 255:
-            LOG.info('Fernet token created with length of %d '
-                     'characters, which exceeds 255 characters',
-                     len(token))
+        if len(token) > CONF.max_token_size:
+            LOG.info(
+                f'Fernet token created with length of {len(token)} '
+                f'characters, which exceeds {CONF.max_token_size} characters'
+            )
 
         return token
 
@@ -183,16 +210,29 @@ class TokenFormatter(object):
 
         for payload_class in _PAYLOAD_CLASSES:
             if version == payload_class.version:
-                (user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id) = payload_class.disassemble(payload)
+                (
+                    user_id,
+                    methods,
+                    system,
+                    project_id,
+                    domain_id,
+                    expires_at,
+                    audit_ids,
+                    trust_id,
+                    federated_group_ids,
+                    identity_provider_id,
+                    protocol_id,
+                    access_token_id,
+                    app_cred_id,
+                    thumbprint,
+                ) = payload_class.disassemble(payload)
                 break
         else:
             # If the token_format is not recognized, raise ValidationError.
-            raise exception.ValidationError(_(
-                'This is not a recognized Fernet payload version: %s') %
-                version)
+            raise exception.ValidationError(
+                _('This is not a recognized Fernet payload version: %s')
+                % version
+            )
 
         # FIXME(lbragstad): Without this, certain token validation tests fail
         # when running with python 3. Once we get further along in this
@@ -208,21 +248,47 @@ class TokenFormatter(object):
         expires_at = timeutils.parse_isotime(expires_at)
         expires_at = ks_utils.isotime(at=expires_at, subsecond=True)
 
-        return (user_id, methods, audit_ids, system, domain_id, project_id,
-                trust_id, federated_group_ids, identity_provider_id,
-                protocol_id, access_token_id, app_cred_id, issued_at,
-                expires_at)
+        return (
+            user_id,
+            methods,
+            audit_ids,
+            system,
+            domain_id,
+            project_id,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+            issued_at,
+            expires_at,
+        )
 
 
-class BasePayload(object):
+class BasePayload:
     # each payload variant should have a unique version
-    version = None
+    version: int
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         """Assemble the payload of a token.
 
         :param user_id: identifier of the user in the token request
@@ -238,6 +304,7 @@ class BasePayload(object):
         :param protocol_id: federated protocol used for authentication
         :param access_token_id: ID of the secret in OAuth1 authentication
         :param app_cred_id: ID of the application credential in effect
+        :param thumbprint: thumbprint of the certificate in OAuth2 mTLS
         :returns: the payload of a token
 
         """
@@ -294,8 +361,12 @@ class BasePayload(object):
 
         """
         time_object = timeutils.parse_isotime(time_string)
-        return (timeutils.normalize_time(time_object) -
-                datetime.datetime.utcfromtimestamp(0)).total_seconds()
+        return (
+            timeutils.normalize_time(time_object)
+            - datetime.datetime.fromtimestamp(
+                0, datetime.timezone.utc
+            ).replace(tzinfo=None)
+        ).total_seconds()
 
     @classmethod
     def _convert_float_to_time_string(cls, time_float):
@@ -305,7 +376,9 @@ class BasePayload(object):
         :returns: a time formatted strings
 
         """
-        time_object = datetime.datetime.utcfromtimestamp(time_float)
+        time_object = datetime.datetime.fromtimestamp(
+            time_float, datetime.timezone.utc
+        ).replace(tzinfo=None)
         return ks_utils.isotime(time_object, subsecond=True)
 
     @classmethod
@@ -373,15 +446,27 @@ class UnscopedPayload(BasePayload):
     version = 0
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
         return (b_user_id, methods, expires_at_int, b_audit_ids)
 
     @classmethod
@@ -400,20 +485,46 @@ class UnscopedPayload(BasePayload):
         protocol_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class DomainScopedPayload(BasePayload):
     version = 1
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         try:
@@ -425,8 +536,7 @@ class DomainScopedPayload(BasePayload):
             else:
                 raise
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
         return (b_user_id, methods, b_domain_id, expires_at_int, b_audit_ids)
 
     @classmethod
@@ -454,26 +564,51 @@ class DomainScopedPayload(BasePayload):
         protocol_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class ProjectScopedPayload(BasePayload):
     version = 2
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         b_project_id = cls.attempt_convert_uuid_hex_to_bytes(project_id)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
         return (b_user_id, methods, b_project_id, expires_at_int, b_audit_ids)
 
     @classmethod
@@ -493,30 +628,61 @@ class ProjectScopedPayload(BasePayload):
         protocol_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class TrustScopedPayload(BasePayload):
     version = 3
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         b_project_id = cls.attempt_convert_uuid_hex_to_bytes(project_id)
         b_trust_id = cls.convert_uuid_hex_to_bytes(trust_id)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
 
-        return (b_user_id, methods, b_project_id, expires_at_int, b_audit_ids,
-                b_trust_id)
+        return (
+            b_user_id,
+            methods,
+            b_project_id,
+            expires_at_int,
+            b_audit_ids,
+            b_trust_id,
+        )
 
     @classmethod
     def disassemble(cls, payload):
@@ -535,10 +701,23 @@ class TrustScopedPayload(BasePayload):
         protocol_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class FederatedUnscopedPayload(BasePayload):
@@ -555,20 +734,39 @@ class FederatedUnscopedPayload(BasePayload):
         return {'id': group_id}
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         b_group_ids = list(map(cls.pack_group_id, federated_group_ids))
         b_idp_id = cls.attempt_convert_uuid_hex_to_bytes(identity_provider_id)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                               audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
 
-        return (b_user_id, methods, b_group_ids, b_idp_id, protocol_id,
-                expires_at_int, b_audit_ids)
+        return (
+            b_user_id,
+            methods,
+            b_group_ids,
+            b_idp_id,
+            protocol_id,
+            expires_at_int,
+            b_audit_ids,
+        )
 
     @classmethod
     def disassemble(cls, payload):
@@ -589,31 +787,64 @@ class FederatedUnscopedPayload(BasePayload):
         trust_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, group_ids, idp_id,
-                protocol_id, access_token_id, app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            group_ids,
+            idp_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class FederatedScopedPayload(FederatedUnscopedPayload):
-    version = None
-
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         b_scope_id = cls.attempt_convert_uuid_hex_to_bytes(
-            project_id or domain_id)
+            project_id or domain_id
+        )
         b_group_ids = list(map(cls.pack_group_id, federated_group_ids))
         b_idp_id = cls.attempt_convert_uuid_hex_to_bytes(identity_provider_id)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                               audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
 
-        return (b_user_id, methods, b_scope_id, b_group_ids, b_idp_id,
-                protocol_id, expires_at_int, b_audit_ids)
+        return (
+            b_user_id,
+            methods,
+            b_scope_id,
+            b_group_ids,
+            b_idp_id,
+            protocol_id,
+            expires_at_int,
+            b_audit_ids,
+        )
 
     @classmethod
     def disassemble(cls, payload):
@@ -624,10 +855,14 @@ class FederatedScopedPayload(FederatedUnscopedPayload):
         scope_id = cls._convert_or_decode(is_stored_as_bytes, scope_id)
         project_id = (
             scope_id
-            if cls.version == FederatedProjectScopedPayload.version else None)
+            if cls.version == FederatedProjectScopedPayload.version
+            else None
+        )
         domain_id = (
             scope_id
-            if cls.version == FederatedDomainScopedPayload.version else None)
+            if cls.version == FederatedDomainScopedPayload.version
+            else None
+        )
         group_ids = list(map(cls.unpack_group_id, payload[3]))
         (is_stored_as_bytes, idp_id) = payload[4]
         idp_id = cls._convert_or_decode(is_stored_as_bytes, idp_id)
@@ -640,9 +875,23 @@ class FederatedScopedPayload(FederatedUnscopedPayload):
         trust_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, group_ids, idp_id,
-                protocol_id, access_token_id, app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            group_ids,
+            idp_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class FederatedProjectScopedPayload(FederatedScopedPayload):
@@ -657,20 +906,39 @@ class OauthScopedPayload(BasePayload):
     version = 7
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         b_project_id = cls.attempt_convert_uuid_hex_to_bytes(project_id)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
         b_access_token_id = cls.attempt_convert_uuid_hex_to_bytes(
-            access_token_id)
-        return (b_user_id, methods, b_project_id, b_access_token_id,
-                expires_at_int, b_audit_ids)
+            access_token_id
+        )
+        return (
+            b_user_id,
+            methods,
+            b_project_id,
+            b_access_token_id,
+            expires_at_int,
+            b_audit_ids,
+        )
 
     @classmethod
     def disassemble(cls, payload):
@@ -680,8 +948,9 @@ class OauthScopedPayload(BasePayload):
         (is_stored_as_bytes, project_id) = payload[2]
         project_id = cls._convert_or_decode(is_stored_as_bytes, project_id)
         (is_stored_as_bytes, access_token_id) = payload[3]
-        access_token_id = cls._convert_or_decode(is_stored_as_bytes,
-                                                 access_token_id)
+        access_token_id = cls._convert_or_decode(
+            is_stored_as_bytes, access_token_id
+        )
         expires_at_str = cls._convert_float_to_time_string(payload[4])
         audit_ids = list(map(cls.base64_encode, payload[5]))
         system = None
@@ -691,26 +960,51 @@ class OauthScopedPayload(BasePayload):
         identity_provider_id = None
         protocol_id = None
         app_cred_id = None
+        thumbprint = None
 
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class SystemScopedPayload(BasePayload):
     version = 8
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
         return (b_user_id, methods, system, expires_at_int, b_audit_ids)
 
     @classmethod
@@ -729,29 +1023,60 @@ class SystemScopedPayload(BasePayload):
         protocol_id = None
         access_token_id = None
         app_cred_id = None
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 class ApplicationCredentialScopedPayload(BasePayload):
     version = 9
 
     @classmethod
-    def assemble(cls, user_id, methods, system, project_id, domain_id,
-                 expires_at, audit_ids, trust_id, federated_group_ids,
-                 identity_provider_id, protocol_id, access_token_id,
-                 app_cred_id):
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
         b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
         methods = auth_plugins.convert_method_list_to_integer(methods)
         b_project_id = cls.attempt_convert_uuid_hex_to_bytes(project_id)
         expires_at_int = cls._convert_time_string_to_float(expires_at)
-        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes,
-                           audit_ids))
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
         b_app_cred_id = cls.attempt_convert_uuid_hex_to_bytes(app_cred_id)
-        return (b_user_id, methods, b_project_id, expires_at_int, b_audit_ids,
-                b_app_cred_id)
+        return (
+            b_user_id,
+            methods,
+            b_project_id,
+            expires_at_int,
+            b_audit_ids,
+            b_app_cred_id,
+        )
 
     @classmethod
     def disassemble(cls, payload):
@@ -771,10 +1096,99 @@ class ApplicationCredentialScopedPayload(BasePayload):
         access_token_id = None
         (is_stored_as_bytes, app_cred_id) = payload[5]
         app_cred_id = cls._convert_or_decode(is_stored_as_bytes, app_cred_id)
-        return (user_id, methods, system, project_id, domain_id,
-                expires_at_str, audit_ids, trust_id, federated_group_ids,
-                identity_provider_id, protocol_id, access_token_id,
-                app_cred_id)
+        thumbprint = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
+
+
+class Oauth2CredentialsScopedPayload(BasePayload):
+    version = 10
+
+    @classmethod
+    def assemble(
+        cls,
+        user_id,
+        methods,
+        system,
+        project_id,
+        domain_id,
+        expires_at,
+        audit_ids,
+        trust_id,
+        federated_group_ids,
+        identity_provider_id,
+        protocol_id,
+        access_token_id,
+        app_cred_id,
+        thumbprint,
+    ):
+        b_user_id = cls.attempt_convert_uuid_hex_to_bytes(user_id)
+        methods = auth_plugins.convert_method_list_to_integer(methods)
+        b_project_id = cls.attempt_convert_uuid_hex_to_bytes(project_id)
+        b_domain_id = cls.attempt_convert_uuid_hex_to_bytes(domain_id)
+        expires_at_int = cls._convert_time_string_to_float(expires_at)
+        b_audit_ids = list(map(cls.random_urlsafe_str_to_bytes, audit_ids))
+        b_thumbprint = (False, thumbprint)
+        return (
+            b_user_id,
+            methods,
+            b_project_id,
+            b_domain_id,
+            expires_at_int,
+            b_audit_ids,
+            b_thumbprint,
+        )
+
+    @classmethod
+    def disassemble(cls, payload):
+        (is_stored_as_bytes, user_id) = payload[0]
+        user_id = cls._convert_or_decode(is_stored_as_bytes, user_id)
+        methods = auth_plugins.convert_integer_to_method_list(payload[1])
+        (is_stored_as_bytes, project_id) = payload[2]
+        project_id = cls._convert_or_decode(is_stored_as_bytes, project_id)
+        (is_stored_as_bytes, domain_id) = payload[3]
+        domain_id = cls._convert_or_decode(is_stored_as_bytes, domain_id)
+        expires_at_str = cls._convert_float_to_time_string(payload[4])
+        audit_ids = list(map(cls.base64_encode, payload[5]))
+        (is_stored_as_bytes, thumbprint) = payload[6]
+        thumbprint = cls._convert_or_decode(is_stored_as_bytes, thumbprint)
+        system = None
+        trust_id = None
+        federated_group_ids = None
+        identity_provider_id = None
+        protocol_id = None
+        access_token_id = None
+        app_cred_id = None
+        return (
+            user_id,
+            methods,
+            system,
+            project_id,
+            domain_id,
+            expires_at_str,
+            audit_ids,
+            trust_id,
+            federated_group_ids,
+            identity_provider_id,
+            protocol_id,
+            access_token_id,
+            app_cred_id,
+            thumbprint,
+        )
 
 
 _PAYLOAD_CLASSES = [
@@ -788,4 +1202,5 @@ _PAYLOAD_CLASSES = [
     OauthScopedPayload,
     SystemScopedPayload,
     ApplicationCredentialScopedPayload,
+    Oauth2CredentialsScopedPayload,
 ]
